@@ -1,9 +1,8 @@
 AIC.rma <- function(object, ..., k=2, correct=FALSE) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
-   if (!inherits(object, "rma"))
-      stop(mstyle$stop("Argument 'object' must be an object of class \"rma\"."))
+   .chkclass(class(object), must="rma")
 
    if (missing(...)) {
 
@@ -41,8 +40,9 @@ AIC.rma <- function(object, ..., k=2, correct=FALSE) {
       ### check that all models were fitted to the same data
 
       yis <- lapply(list(object, ...), function(x) as.vector(x$yi))
+
       if (!all(sapply(yis[-1], function(x) identical(x, yis[[1]]))))
-         warning(mstyle$warning("Models not all fitted to the same data."))
+         warning(mstyle$warning("Models not all fitted to the same data."), call.=FALSE)
 
    }
 
