@@ -1,6 +1,6 @@
 anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="rma", notap=c("rma.mh", "rma.peto"), notav="rma.glmm")
 
@@ -12,17 +12,23 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
 
    ddd <- list(...)
 
-   .chkdots(ddd, c("test", "L", "verbose"))
+   .chkdots(ddd, c("test", "L", "verbose", "fixed"))
 
    if (!is.null(ddd$L))
       X <- ddd$L
 
+   fixed <- .chkddd(ddd$fixed, FALSE, .isTRUE(ddd$fixed))
+
    if (!missing(att) && !inherits(object, "rma.ls"))
       stop(mstyle$stop("Can only specify 'att' for location-scale models."))
 
    if (!missing(Z) && !inherits(object, "rma.ls"))
       stop(mstyle$stop("Can only specify 'Z' for location-scale models."))
 
+   #mf <- match.call()
+   #if (any(grepl("pairwise(", as.character(mf), fixed=TRUE)))
+   #   try(assign("pairwise", object, envir=.metafor), silent=TRUE)
+
    if (missing(object2)) {
 
       ### if only 'object' has been specified, can use function to test one or multiple coefficients
@@ -45,15 +51,36 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
             if (missing(att) || is.null(att)) {
                att <- x$att
             } else {
-               att <- .set.btt(att, x$q, x$Z.int.incl, colnames(x$Z))
+               if (is.character(att) && length(att) > 1L)
+                  att <- as.list(att)
+               if (is.list(att)) {
+                  if (!missing(rhs))
+                     stop(mstyle$stop("Cannot use 'rhs' argument when specifying a list for 'att'."))
+                  sav <- lapply(att, function(attj) anova(x, att=attj, digits=digits, fixed=fixed))
+                  names(sav) <- sapply(att, .format.btt)
+                  class(sav) <- "list.anova.rma"
+                  return(sav)
+               }
+               att <- .set.btt(att, x$q, x$Z.int.incl, colnames(x$Z), fixed=fixed)
             }
 
             m <- length(att)
 
+            if (missing(rhs)) {
+               rhs <- rep(0, m)
+            } else {
+               if (length(rhs) == 1L)
+                  rhs <- rep(rhs, m)
+               if (length(rhs) != m)
+                  stop(mstyle$stop(paste0("Length of 'rhs' (", length(rhs), ") does not match the number of coefficients tested (", m, ").")))
+            }
+
+            x$alpha[att,] <- x$alpha[att,] - rhs
+
             QS <- try(as.vector(t(x$alpha)[att] %*% chol2inv(chol(x$va[att,att])) %*% x$alpha[att]), silent=TRUE)
 
             if (inherits(QS, "try-error"))
-               QS <- NA
+               QS <- NA_real_
 
             if (is.element(x$test, c("knha","adhoc","t"))) {
                QS   <- QS / m
@@ -73,11 +100,32 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
             if (missing(btt) || is.null(btt)) {
                btt <- x$btt
             } else {
-               btt <- .set.btt(btt, x$p, x$int.incl, colnames(x$X))
+               if (is.character(btt) && length(btt) > 1L)
+                  btt <- as.list(btt)
+               if (is.list(btt)) {
+                  if (!missing(rhs))
+                     stop(mstyle$stop("Cannot use 'rhs' argument when specifying a list for 'btt'."))
+                  sav <- lapply(btt, function(bttj) anova(x, btt=bttj, digits=digits, fixed=fixed))
+                  names(sav) <- sapply(btt, .format.btt)
+                  class(sav) <- "list.anova.rma"
+                  return(sav)
+               }
+               btt <- .set.btt(btt, x$p, x$int.incl, colnames(x$X), fixed=fixed)
             }
 
             m <- length(btt)
 
+            if (missing(rhs)) {
+               rhs <- rep(0, m)
+            } else {
+               if (length(rhs) == 1L)
+                  rhs <- rep(rhs, m)
+               if (length(rhs) != m)
+                  stop(mstyle$stop(paste0("Length of 'rhs' (", length(rhs), ") does not match the number of coefficients tested (", m, ").")))
+            }
+
+            x$b[btt,] <- x$beta[btt,] <- x$b[btt,] - rhs
+
             if (inherits(x, "robust.rma") && x$robumethod == "clubSandwich") {
 
                cs.wald <- try(clubSandwich::Wald_test(x, cluster=x$cluster, vcov=x$vb, test=x$wald_test, constraints=clubSandwich::constrain_zero(btt)), silent=!isTRUE(ddd$verbose))
@@ -91,17 +139,18 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
 
             } else {
 
+               #QM <- try(as.vector(t((x$beta)[btt]-rhs) %*% chol2inv(chol(x$vb[btt,btt])) %*% (x$beta[btt]-rhs)), silent=TRUE)
                QM <- try(as.vector(t(x$beta)[btt] %*% chol2inv(chol(x$vb[btt,btt])) %*% x$beta[btt]), silent=TRUE)
 
                if (inherits(QM, "try-error"))
-                  QM <- NA
+                  QM <- NA_real_
 
                if (is.element(x$test, c("knha","adhoc","t"))) {
                   QM   <- QM / m
                   QMdf <- c(m, x$QMdf[2])
                   QMp  <- pf(QM, df1=QMdf[1], df2=QMdf[2], lower.tail=FALSE)
                } else {
-                  QMdf <- c(m, NA)
+                  QMdf <- c(m, NA_integer_)
                   QMp  <- pchisq(QM, df=QMdf[1], lower.tail=FALSE)
                }
 
@@ -159,29 +208,29 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
             zval <- c(Za/se)
 
             if (is.element(x$test, c("knha","adhoc","t"))) {
-               pval <- if (x$ddf.alpha > 0) 2*pt(abs(zval), df=x$ddf.alpha, lower.tail=FALSE) else rep(NA,m)
+               pval <- if (x$ddf.alpha > 0) 2*pt(abs(zval), df=x$ddf.alpha, lower.tail=FALSE) else rep(NA_real_,m)
             } else {
                pval <- 2*pnorm(abs(zval), lower.tail=FALSE)
             }
 
             ### omnibus test of all hypotheses (only possible if 'Z' is of full rank)
 
-            QS  <- NA ### need this in case QS cannot be calculated below
-            QSp <- NA ### need this in case QSp cannot be calculated below
+            QS  <- NA_real_ # need this in case QS cannot be calculated below
+            QSp <- NA_real_ # need this in case QSp cannot be calculated below
 
             if (rankMatrix(Z) == m) {
 
                QS <- try(as.vector(t(Za) %*% chol2inv(chol(vZa)) %*% Za), silent=TRUE)
 
                if (inherits(QS, "try-error"))
-                  QS <- NA
+                  QS <- NA_real_
 
                if (is.element(x$test, c("knha","adhoc","t"))) {
                   QS   <- QS / m
                   QSdf <- c(m, x$QSdf[2])
-                  QSp  <- if (QSdf[2] > 0) pf(QS, df1=QSdf[1], df2=QSdf[2], lower.tail=FALSE) else NA
+                  QSp  <- if (QSdf[2] > 0) pf(QS, df1=QSdf[1], df2=QSdf[2], lower.tail=FALSE) else NA_real_
                } else {
-                  QSdf <- c(m, NA)
+                  QSdf <- c(m, NA_integer_)
                   QSp  <- pchisq(QS, df=QSdf[1], lower.tail=FALSE)
                }
 
@@ -191,20 +240,24 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
 
             hyp <- rep("", m)
             for (j in seq_len(m)) {
-               Zj <- round(Z[j,], digits[["est"]]) ### coefficients for the jth contrast
-               sel <- Zj != 0 ### TRUE if coefficient is != 0
-               hyp[j] <- paste(paste(Zj[sel], rownames(x$alpha)[sel], sep="*"), collapse=" + ") ### coefficient*variable + coefficient*variable ...
-               hyp[j] <- gsub("1*", "", hyp[j], fixed=TRUE) ### turn '+1' into '+' and '-1' into '-'
-               hyp[j] <- gsub("+ -", "- ", hyp[j], fixed=TRUE) ### turn '+ -' into '-'
+               Zj <- round(Z[j,], digits[["est"]]) # coefficients for the jth contrast
+               sel <- Zj != 0 # TRUE if coefficient is != 0
+               hyp[j] <- paste(paste(Zj[sel], rownames(x$alpha)[sel], sep="*"), collapse=" + ") # coefficient*variable + coefficient*variable ...
+               hyp[j] <- gsub("1*", "", hyp[j], fixed=TRUE) # turn '+1' into '+' and '-1' into '-'
+               hyp[j] <- gsub("+ -", "- ", hyp[j], fixed=TRUE) # turn '+ -' into '-'
             }
             if (identical(rhs, rep(0,m))) {
-               hyp <- paste0(hyp, " = 0") ### add '= 0' at the right
+               hyp <- paste0(hyp, " = 0") # add '= 0' at the right
             } else {
-               hyp <- paste0(hyp, " = ", .fcf(rhs, digits=digits[["est"]])) ### add '= rhs' at the right
+               if (length(unique(rhs)) == 1L) {
+                  hyp <- paste0(hyp, " = ", round(rhs, digits=digits[["est"]])) # add '= rhs' at the right
+               } else {
+                  hyp <- paste0(hyp, " = ", fmtx(rhs, digits=digits[["est"]])) # add '= rhs' at the right
+               }
             }
             hyp <- data.frame(hyp, stringsAsFactors=FALSE)
             colnames(hyp) <- ""
-            rownames(hyp) <- paste0(seq_len(m), ":") ### add '1:', '2:', ... as row names
+            rownames(hyp) <- paste0(seq_len(m), ":") # add '1:', '2:', ... as row names
 
             res <- list(QS=QS, QSdf=QSdf, QSp=QSp, hyp=hyp, Za=Za, se=se, zval=zval, pval=pval, k=x$k, q=x$q, m=m, test=x$test, ddf=x$ddf.alpha, digits=digits, type="Wald.Za")
 
@@ -241,7 +294,7 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
                ddf <- cs.lc$df
 
                if (!missing(rhs))
-                  warning(mstyle$warning("Cannot use 'rhs' argument for 'robust.rma' objects based on 'clubSandwich'."))
+                  warning(mstyle$warning("Cannot use 'rhs' argument for 'robust.rma' objects based on 'clubSandwich'."), call.=FALSE)
 
                rhs <- rep(0, m)
 
@@ -252,9 +305,9 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
 
                ### omnibus test of all hypotheses (only possible if 'X' is of full rank)
 
-               QM   <- NA ### need this in case QMp cannot be calculated below
-               QMdf <- NA ### need this in case X is not of full rank
-               QMp  <- NA ### need this in case QMp cannot be calculated below
+               QM   <- NA_real_    # need this in case QMp cannot be calculated below
+               QMp  <- NA_real_    # need this in case QMp cannot be calculated below
+               QMdf <- NA_integer_ # need this in case X is not of full rank
 
                if (rankMatrix(X) == m) {
 
@@ -277,14 +330,14 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
                   if (length(x$ddf) == 1L) {
                      ddf <- rep(x$ddf, m)
                   } else {
-                     ddf <- rep(NA, m)
+                     ddf <- rep(NA_integer_, m)
                      for (j in seq_len(m)) {
                         bn0 <- X[j,] != 0
                         ddf[j] <- min(x$ddf[bn0])
                      }
                   }
                } else {
-                  ddf <- rep(NA, m)
+                  ddf <- rep(NA_integer_, m)
                }
 
                ### specification of the right-hand side
@@ -307,16 +360,16 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
                zval <- c(Xb/se)
 
                if (is.element(x$test, c("knha","adhoc","t"))) {
-                  pval <- sapply(seq_along(ddf), function(j) if (ddf[j] > 0) 2*pt(abs(zval[j]), df=ddf[j], lower.tail=FALSE) else NA)
+                  pval <- sapply(seq_along(ddf), function(j) if (ddf[j] > 0) 2*pt(abs(zval[j]), df=ddf[j], lower.tail=FALSE) else NA_real_)
                } else {
                   pval <- 2*pnorm(abs(zval), lower.tail=FALSE)
                }
 
                ### omnibus test of all hypotheses (only possible if 'X' is of full rank)
 
-               QM   <- NA ### need this in case QMp cannot be calculated below
-               QMdf <- NA ### need this in case X is not of full rank
-               QMp  <- NA ### need this in case QMp cannot be calculated below
+               QM   <- NA_real_    # need this in case QMp cannot be calculated below
+               QMp  <- NA_real_    # need this in case QMp cannot be calculated below
+               QMdf <- NA_integer_ # need this in case X is not of full rank
 
                if (rankMatrix(X) == m) {
 
@@ -328,14 +381,14 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
                   QM <- try(as.vector(t(Xb) %*% chol2inv(chol(vXb)) %*% Xb), silent=TRUE)
 
                   if (inherits(QM, "try-error"))
-                     QM <- NA
+                     QM <- NA_real_
 
                   if (is.element(x$test, c("knha","adhoc","t"))) {
                      QM   <- QM / m
                      QMdf <- c(m, min(ddf))
-                     QMp  <- if (QMdf[2] > 0) pf(QM, df1=QMdf[1], df2=QMdf[2], lower.tail=FALSE) else NA
+                     QMp  <- if (QMdf[2] > 0) pf(QM, df1=QMdf[1], df2=QMdf[2], lower.tail=FALSE) else NA_real_
                   } else {
-                     QMdf <- c(m, NA)
+                     QMdf <- c(m, NA_integer_)
                      QMp  <- pchisq(QM, df=QMdf[1], lower.tail=FALSE)
                   }
 
@@ -347,20 +400,24 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
 
             hyp <- rep("", m)
             for (j in seq_len(m)) {
-               Xj <- round(X[j,], digits[["est"]]) ### coefficients for the jth contrast
-               sel <- Xj != 0 ### TRUE if coefficient is != 0
-               hyp[j] <- paste(paste(Xj[sel], rownames(x$beta)[sel], sep="*"), collapse=" + ") ### coefficient*variable + coefficient*variable ...
-               hyp[j] <- gsub("1*", "", hyp[j], fixed=TRUE) ### turn '+1' into '+' and '-1' into '-'
-               hyp[j] <- gsub("+ -", "- ", hyp[j], fixed=TRUE) ### turn '+ -' into '-'
+               Xj <- round(X[j,], digits[["est"]]) # coefficients for the jth contrast
+               sel <- Xj != 0 # TRUE if coefficient is != 0
+               hyp[j] <- paste(paste(Xj[sel], rownames(x$beta)[sel], sep="*"), collapse=" + ") # coefficient*variable + coefficient*variable ...
+               hyp[j] <- gsub("1*", "", hyp[j], fixed=TRUE) # turn '+1' into '+' and '-1' into '-'
+               hyp[j] <- gsub("+ -", "- ", hyp[j], fixed=TRUE) # turn '+ -' into '-'
             }
             if (identical(rhs, rep(0,m))) {
-               hyp <- paste0(hyp, " = 0") ### add '= 0' at the right
+               hyp <- paste0(hyp, " = 0") # add '= 0' at the right
             } else {
-               hyp <- paste0(hyp, " = ", .fcf(rhs, digits=digits[["est"]])) ### add '= rhs' at the right
+               if (length(unique(rhs)) == 1L) {
+                  hyp <- paste0(hyp, " = ", round(rhs, digits=digits[["est"]])) # add '= rhs' at the right
+               } else {
+                  hyp <- paste0(hyp, " = ", fmtx(rhs,  digits=digits[["est"]])) # add '= rhs' at the right
+               }
             }
             hyp <- data.frame(hyp, stringsAsFactors=FALSE)
             colnames(hyp) <- ""
-            rownames(hyp) <- paste0(seq_len(m), ":") ### add '1:', '2:', ... as row names
+            rownames(hyp) <- paste0(seq_len(m), ":") # add '1:', '2:', ... as row names
 
             res <- list(QM=QM, QMdf=QMdf, QMp=QMp, hyp=hyp, Xb=Xb, se=se, zval=zval, pval=pval, k=x$k, p=x$p, m=m, test=x$test, ddf=ddf, digits=digits, type="Wald.Xb")
 
@@ -377,19 +434,15 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
          stop(mstyle$stop("Argument 'object2' must be an object of class \"rma\"."))
 
       if (inherits(object2, c("rma.mh","rma.peto")))
-         stop(mstyle$stop("Function not applicable for objects of class \"rma.mh\" or \"rma.peto\"."))
+         stop(mstyle$stop("Function not applicable to objects of class \"rma.mh\" or \"rma.peto\"."))
 
       if (inherits(object2, "rma.glmm"))
          stop(mstyle$stop("Method not available for objects of class \"rma.glmm\"."))
 
       if (!identical(class(object), class(object2)))
-         stop(mstyle$stop("Class of 'object1' must be the same as class of 'object2'."))
+         stop(mstyle$stop("Class of 'object' must be the same as class of 'object2'."))
 
-      if (!is.null(ddd$test)) {
-         test <- match.arg(ddd$test, c("LRT", "Wald"))
-      } else {
-         test <- "LRT"
-      }
+      test <- .chkddd(ddd$test, "LRT", match.arg(ddd$test, c("LRT", "Wald")))
 
       ### assume 'object' is the full model and 'object2' the reduced model
 
@@ -416,14 +469,16 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
       }
 
       ### check if models are based on the same data (TODO: also check for same weights?)
+      ### note: using as.vector() to strip attributes/names, as.matrix() to make both V matrices non-sparse, and
+      ###       isTRUE(all.equal()) because conversion to non-sparse can introduce some negligible discrepancies
 
       if (inherits(object, "rma.uni")) {
-         if (!(identical(as.vector(model.f$yi), as.vector(model.r$yi)) && identical(as.vector(model.f$vi), as.vector(model.r$vi)))) ### as.vector() to strip attributes/names
+         if (!(identical(as.vector(model.f$yi), as.vector(model.r$yi)) && isTRUE(all.equal(as.vector(model.f$vi), as.vector(model.r$vi)))))
             stop(mstyle$stop("Observed outcomes and/or sampling variances not equal in the full and reduced model."))
       }
 
       if (inherits(object, "rma.mv")) {
-         if (!(identical(as.vector(model.f$yi), as.vector(model.r$yi)) && identical(as.matrix(model.f$V), as.matrix(model.r$V)))) ### as.vector() to strip attributes/names, as.matrix() to make both V matrices non-sparse
+         if (!(identical(as.vector(model.f$yi), as.vector(model.r$yi)) && isTRUE(all.equal(as.matrix(model.f$V), as.matrix(model.r$V)))))
             stop(mstyle$stop("Observed outcomes and/or sampling variances/covariances not equal in the full and reduced model."))
       }
 
@@ -445,16 +500,31 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
       ### for LRTs, using anything besides ML/REML is strictly speaking incorrect
 
       if (test == "LRT" && (!is.element(model.f$method, c("FE","EE","CE","ML","REML")) || !is.element(model.r$method, c("FE","EE","CE","ML","REML"))))
-         warning(mstyle$warning("LRTs should be based on ML/REML estimation."))
+         warning(mstyle$warning("LRTs should be based on ML/REML estimation."), call.=FALSE)
 
       ### for LRTs based on REML estimation, check if fixed effects differ
       if (test == "LRT" && model.f$method == "REML" && (!identical(model.f$X, model.r$X))) {
          if (refit) {
             #message(mstyle$message("Refitting models with ML (instead of REML) estimation ..."))
-            model.f <- try(update(model.f, method="ML"), silent=TRUE)
+            if (inherits(model.f, "rma.uni") && model.f$model == "rma.uni") {
+               #model.f <- try(update(model.f, method="ML", data=model.f$data), silent=TRUE)
+               args <- list(yi=model.f$yi, vi=model.f$vi, weights=model.f$weights, mods=model.f$X, intercept=FALSE, method="ML", weighted=model.f$weighted,
+                            test=model.f$test, level=model.f$level, tau2=ifelse(model.f$tau2.fix, model.f$tau2, NA), control=model.f$control, skipr2=TRUE)
+               model.f <- try(suppressWarnings(.do.call(rma.uni, args)), silent=TRUE)
+            } else {
+               # note: this fails when building the docs with pkgdown; not sure why; the approach above at least works for 'rma.uni' objects and is more efficient as it skips the R^2 calculation
+               model.f <- try(update(model.f, method="ML"), silent=TRUE)
+            }
             if (inherits(model.f, "try-error"))
                stop(mstyle$stop("Refitting the full model with ML estimation failed."))
-            model.r <- try(update(model.r, method="ML"), silent=TRUE)
+            if (inherits(model.r, "rma.uni") && model.r$model == "rma.uni") {
+               #model.r <- try(update(model.r, method="ML", data=model.r$data), silent=TRUE)
+               args <- list(yi=model.r$yi, vi=model.r$vi, weights=model.r$weights, mods=model.r$X, intercept=FALSE, method="ML", weighted=model.r$weighted,
+                            test=model.r$test, level=model.r$level, tau2=ifelse(model.r$tau2.fix, model.r$tau2, NA), control=model.r$control, skipr2=TRUE)
+               model.r <- try(suppressWarnings(.do.call(rma.uni, args)), silent=TRUE)
+            } else {
+               model.r <- try(update(model.r, method="ML"), silent=TRUE)
+            }
             if (inherits(model.r, "try-error"))
                stop(mstyle$stop("Refitting the reduced model with ML estimation failed."))
             parms.f <- model.f$parms
@@ -476,7 +546,7 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
       ### for 'rma.uni' objects, calculate pseudo R^2 value (based on the
       ### proportional reduction in tau^2) comparing full vs. reduced model
 
-      if (inherits(object, "rma.uni") && !inherits(object, "rma.ls") && !inherits(object2, "rma.ls")) {
+      if (inherits(object, "rma.uni") && !inherits(object, "rma.ls") && !inherits(object, "rma.gen")) {
          if (is.element(model.f$method, c("FE","EE","CE"))) {
             if (model.f$weighted) {
                if (is.null(model.f$weights)) {
@@ -505,17 +575,17 @@ anova.rma <- function(object, object2, btt, X, att, Z, rhs, digits, refit=FALSE,
             R2 <- 100 * max(0, (model.r$tau2 - model.f$tau2) / model.r$tau2)
          }
       } else {
-         R2 <- NA
+         R2 <- NA_real_
       }
 
       ### for 'rma.uni' objects, extract tau^2 estimates
 
-      if (inherits(object, "rma.uni") && !inherits(object, "rma.ls") && !inherits(object2, "rma.ls")) {
+      if (inherits(object, "rma.uni") && !inherits(object, "rma.ls") && !inherits(object, "rma.gen")) {
          tau2.f <- model.f$tau2
          tau2.r <- model.r$tau2
       } else {
-         tau2.f <- NA
-         tau2.r <- NA
+         tau2.f <- NA_real_
+         tau2.r <- NA_real_
       }
 
       if (test == "LRT") {
