@@ -1,11 +1,11 @@
 blsplit <- function(x, cluster, fun, args, sort=FALSE) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (missing(cluster))
       stop(mstyle$stop("Must specify 'cluster' variable."))
 
-   if (!is.matrix(x))
+   if (!is.matrix(x) && !inherits(x, "dgCMatrix"))
       stop(mstyle$stop("Argument 'x' must be a matrix."))
 
    if (!isSymmetric(x))
