@@ -1,6 +1,6 @@
 confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, delta, digits, transf, targs, verbose=FALSE, control, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="rma.uni.selmodel")
 
@@ -9,9 +9,12 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
 
    x <- object
 
-   if (x$betaspec) ### TODO: consider providing CIs also for this case
+   if (x$betaspec) # TODO: consider providing CIs also for this case
       stop(mstyle$stop("Cannot obtain confidence intervals when one or more beta values were fixed."))
 
+   if (x$decreasing || x$type == "stepcon")
+      stop(mstyle$stop("Method not currently implemented for this type of model."))
+
    k <- x$k
    p <- x$p
 
@@ -33,12 +36,12 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
    if (missing(control))
       control <- list()
 
-   level <- .level(level)
-
    ddd <- list(...)
 
    .chkdots(ddd, c("time", "xlim", "extint"))
 
+   level <- .level(level, stopon100=.isTRUE(ddd$extint))
+
    if (.isTRUE(ddd$time))
       time.start <- proc.time()
 
@@ -114,7 +117,7 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
 
    if (random) {
 
-      type <- "PL"
+      type <- "pl"
 
       ######################################################################
 
@@ -210,11 +213,11 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
 
       vc.lb <- NA_real_
       vc.ub <- NA_real_
-      ci.null <- FALSE ### logical if CI is a null set
-      lb.conv <- FALSE ### logical if search converged for lower bound (LB)
-      ub.conv <- FALSE ### logical if search converged for upper bound (UB)
-      lb.sign <- ""    ### for sign in case LB must be below vc.min ("<") or above vc.max (">")
-      ub.sign <- ""    ### for sign in case UB must be below vc.min ("<") or above vc.max (">")
+      ci.null <- FALSE # logical if CI is a null set
+      lb.conv <- FALSE # logical if search converged for lower bound (LB)
+      ub.conv <- FALSE # logical if search converged for upper bound (UB)
+      lb.sign <- ""    # for sign in case LB must be below vc.min ("<") or above vc.max (">")
+      ub.sign <- ""    # for sign in case UB must be below vc.min ("<") or above vc.max (">")
 
       ######################################################################
       ######################################################################
@@ -224,7 +227,7 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
 
       # TODO: could also provide Wald-type CIs (ci.lb.tau2, ci.ub.tau2) and (ci.lb.delta, ci.ub.delta)
 
-      if (type == "PL") {
+      if (type == "pl") {
 
          if (con$vc.min > vc)
             stop(mstyle$stop("Lower bound of interval to be searched must be <= estimated value of component."))
@@ -268,6 +271,7 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
                   }
 
                   ### check if uniroot method converged
+
                   if (!inherits(res, "try-error")) {
                      vc.lb <- res
                      lb.conv <- TRUE
@@ -321,6 +325,7 @@ confint.rma.uni.selmodel <- function(object, parm, level, fixed=FALSE, tau2, del
                   }
 
                   ### check if uniroot method converged
+
                   if (!inherits(res, "try-error")) {
                      vc.ub <- res
                      ub.conv <- TRUE
