@@ -1,6 +1,6 @@
 cumul.rma.mh <- function(x, order, digits, transf, targs, progbar=FALSE, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(x), must="rma.mh")
 
@@ -29,11 +29,7 @@ cumul.rma.mh <- function(x, order, digits, transf, targs, progbar=FALSE, ...) {
    if (.isTRUE(ddd$time))
       time.start <- proc.time()
 
-   if (is.null(ddd$decreasing)) {
-      decreasing <- FALSE
-   } else {
-      decreasing <- ddd$decreasing
-   }
+   decreasing <- .chkddd(ddd$decreasing, FALSE)
 
    #########################################################################
 
@@ -50,9 +46,9 @@ cumul.rma.mh <- function(x, order, digits, transf, targs, progbar=FALSE, ...) {
    if (length(order) != x$k.all)
       stop(mstyle$stop(paste0("Length of the 'order' argument (", length(order), ") does not correspond to the size of the original dataset (", x$k.all, ").")))
 
-   ### note: order variable is assumed to be of the same length as the size of the
-   ###       original dataset passed to the model fitting function and so we apply
-   ###       the same subsetting (if necessary) as was done during model fitting
+   ### note: order variable must be of the same length as the original dataset
+   ###       so we have to apply the same subsetting (if necessary)
+   ###       as was done during model fitting
 
    order <- .getsubset(order, x$subset)
 
@@ -137,7 +133,7 @@ cumul.rma.mh <- function(x, order, digits, transf, targs, progbar=FALSE, ...) {
 
    ### if requested, apply transformation function
 
-   if (.isTRUE(transf) && is.element(x$measure, c("OR","RR","IRR"))) ### if transf=TRUE, apply exp transformation to ORs, RRs, and IRRs
+   if (.isTRUE(transf) && is.element(x$measure, c("OR","RR","IRR"))) # if transf=TRUE, apply exp transformation to ORs, RRs, and IRRs
       transf <- exp
 
    if (is.function(transf)) {
