@@ -1,6 +1,6 @@
 cumul.rma.peto <- function(x, order, digits, transf, targs, progbar=FALSE, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(x), must="rma.peto")
 
@@ -29,11 +29,7 @@ cumul.rma.peto <- function(x, order, digits, transf, targs, progbar=FALSE, ...)
    if (.isTRUE(ddd$time))
       time.start <- proc.time()
 
-   if (is.null(ddd$decreasing)) {
-      decreasing <- FALSE
-   } else {
-      decreasing <- ddd$decreasing
-   }
+   decreasing <- .chkddd(ddd$decreasing, FALSE)
 
    #########################################################################
 
@@ -50,24 +46,28 @@ cumul.rma.peto <- function(x, order, digits, transf, targs, progbar=FALSE, ...)
    if (length(order) != x$k.all)
       stop(mstyle$stop(paste0("Length of the 'order' argument (", length(order), ") does not correspond to the size of the original dataset (", x$k.all, ").")))
 
-   ### note: order variable is assumed to be of the same length as the size of the
-   ###       original dataset passed to the model fitting function and so we apply
-   ###       the same subsetting (if necessary) as was done during model fitting
+   ### note: order variable must be of the same length as the original dataset
+   ###       so we have to apply the same subsetting (if necessary)
+   ###       as was done during model fitting
 
-   if (!is.null(x$subset))
-      order <- order[x$subset]
+   order <- .getsubset(order, x$subset)
 
    order <- order(order, decreasing=decreasing)
 
-   ai.f   <- x$ai.f[order]
-   bi.f   <- x$bi.f[order]
-   ci.f   <- x$ci.f[order]
-   di.f   <- x$di.f[order]
+   ai.f   <- x$outdat.f$ai[order]
+   bi.f   <- x$outdat.f$bi[order]
+   ci.f   <- x$outdat.f$ci[order]
+   di.f   <- x$outdat.f$di[order]
    yi.f   <- x$yi.f[order]
    vi.f   <- x$vi.f[order]
    not.na <- x$not.na[order]
    slab   <- x$slab[order]
    ids    <- x$ids[order]
+   if (inherits(x$data, "environment")) {
+      data <- NULL
+   } else {
+      data <- x$data[order,]
+   }
 
    beta  <- rep(NA_real_, x$k.f)
    se    <- rep(NA_real_, x$k.f)
@@ -123,18 +123,18 @@ cumul.rma.peto <- function(x, order, digits, transf, targs, progbar=FALSE, ...)
 
    ### if requested, apply transformation function
 
-   if (.isTRUE(transf)) ### if transf=TRUE, apply exp transformation to ORs
+   if (.isTRUE(transf)) # if transf=TRUE, apply exp transformation to ORs
       transf <- exp
 
    if (is.function(transf)) {
       if (is.null(targs)) {
          beta  <- sapply(beta, transf)
-         se    <- rep(NA,x$k.f)
+         se    <- rep(NA_real_, x$k.f)
          ci.lb <- sapply(ci.lb, transf)
          ci.ub <- sapply(ci.ub, transf)
       } else {
          beta  <- sapply(beta, transf, targs)
-         se    <- rep(NA,x$k.f)
+         se    <- rep(NA_real_, x$k.f)
          ci.lb <- sapply(ci.lb, transf, targs)
          ci.ub <- sapply(ci.ub, transf, targs)
       }
@@ -153,12 +153,14 @@ cumul.rma.peto <- function(x, order, digits, transf, targs, progbar=FALSE, ...)
       out <- list(estimate=beta[not.na], se=se[not.na], zval=zval[not.na], pval=pval[not.na], ci.lb=ci.lb[not.na], ci.ub=ci.ub[not.na], Q=QE[not.na], Qp=QEp[not.na], I2=I2[not.na], H2=H2[not.na])
       out$slab <- slab[not.na]
       out$ids  <- ids[not.na]
+      out$data <- data[not.na,]
    }
 
    if (na.act == "na.exclude" || na.act == "na.pass") {
       out <- list(estimate=beta, se=se, zval=zval, pval=pval, ci.lb=ci.lb, ci.ub=ci.ub, Q=QE, Qp=QEp, I2=I2, H2=H2)
       out$slab <- slab
       out$ids  <- ids
+      out$data <- data
    }
 
    if (na.act == "na.fail" && any(!x$not.na))
