@@ -8,7 +8,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    na.act <- getOption("na.action")
 
@@ -27,6 +27,8 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (is.function(transf) && is.function(atransf))
       stop(mstyle$stop("Use either 'transf' or 'atransf' to specify a transformation (not both)."))
 
+   .start.plot()
+
    yi <- x
 
    if (missing(targs))
@@ -62,13 +64,8 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (missing(shade))
       shade <- NULL
 
-   if (missing(colshade)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         colshade <- "gray20"
-      } else {
-         colshade <- "gray90"
-      }
-   }
+   if (missing(colshade))
+      colshade <- .coladj(par("bg","fg"), dark=0.1, light=-0.1)
 
    if (missing(cex))
       cex <- NULL
@@ -98,7 +95,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    ### set default line types if user has not specified 'lty' argument
 
    if (missing(lty)) {
-      lty <- c("solid", "solid") # 1st value = CIs, 2nd value = horizontal line(s)
+      lty <- c("solid", "solid") # 1st = CIs, 2nd = horizontal line(s)
    } else {
       if (length(lty) == 1L)
          lty <- c(lty, "solid")
@@ -109,18 +106,31 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (length(efac) == 1L)
       efac <- rep(efac, 2L)
 
+   efac[efac == 0] <- NA
+
    ### annotation symbols vector
 
    if (is.null(ddd$annosym)) {
-      annosym <- c(" [", ", ", "]", "-") # 4th element for minus sign symbol
+      annosym <- c(" [", ", ", "]", "-", " ") # 4th element for minus sign symbol; 5th for space (in place of numbers and +); see [a]
    } else {
       annosym <- ddd$annosym
       if (length(annosym) == 3L)
-         annosym <- c(annosym, "-")
-      if (length(annosym) != 4L)
-         stop(mstyle$stop("Argument 'annosym' must be a vector of length 3 (or 4)."))
+         annosym <- c(annosym, "-", " ")
+      if (length(annosym) == 4L)
+         annosym <- c(annosym, " ")
+      if (length(annosym) != 5L)
+         stop(mstyle$stop("Argument 'annosym' must be a vector of length 3 (or 4 or 5)."))
    }
 
+   ### adjust annosym for tabular figures
+
+   if (isTRUE(ddd$tabfig == 1))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2212", "\u2002") # \u2009 thin space; \u2212 minus, \u2002 en space
+   if (isTRUE(ddd$tabfig == 2))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2013", "\u2002") # \u2009 thin space; \u2013 en dash, \u2002 en space
+   if (isTRUE(ddd$tabfig == 3))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2212", "\u2007") # \u2009 thin space; \u2212 minus, \u2007 figure space
+
    ### set measure based on the measure attribute of yi
 
    if (is.null(attr(yi, "measure"))) {
@@ -159,11 +169,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (!annotate)
       header.right <- NULL
 
-   if (is.null(ddd$decreasing)) {
-      decreasing <- FALSE
-   } else {
-      decreasing <- ddd$decreasing
-   }
+   decreasing <- .chkddd(ddd$decreasing, FALSE)
 
    if (!is.null(ddd$clim))
       olim <- ddd$clim
@@ -180,11 +186,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          rowadj <- c(rowadj,0) # if two values are specified, use them for 1&2
    }
 
-   if (is.null(ddd$top)) {
-      top <- 3
-   } else {
-      top <- ddd$top
-   }
+   top <- .chkddd(ddd$top, 3)
 
    if (is.null(ddd$xlabadj)) {
       xlabadj <- c(NA,NA)
@@ -194,27 +196,23 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          xlabadj <- c(xlabadj, 1-xlabadj)
    }
 
-   if (is.null(ddd$xlabfont)) {
-      xlabfont <- 1
-   } else {
-      xlabfont <- ddd$xlabfont
-   }
+   xlabfont <- .chkddd(ddd$xlabfont, 1)
 
-   lplot     <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) plot(...)
-   labline   <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) abline(...)
-   lsegments <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) segments(...)
-   laxis     <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) axis(...)
-   lmtext    <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) mtext(...)
-   lpolygon  <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) polygon(...)
-   ltext     <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) text(...)
-   lpoints   <- function(..., textpos, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) points(...)
+   lplot     <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) plot(...)
+   labline   <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) abline(...)
+   lsegments <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) segments(...)
+   laxis     <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) axis(...)
+   lmtext    <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) mtext(...)
+   lpolygon  <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) polygon(...)
+   ltext     <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) text(...)
+   lpoints   <- function(..., textpos, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) points(...)
 
    #########################################################################
 
    ### extract data, study labels, and other arguments
 
    if (!missing(vi) && is.function(vi)) # if vi is utils::vi()
-      stop(mstyle$stop("Cannot find variable specified for 'vi' argument."), call.=FALSE)
+      stop(mstyle$stop("Cannot find variable specified for 'vi' argument."))
 
    if (hasArg(ci.lb) && hasArg(ci.ub)) {     # CI bounds are specified by user
       if (length(ci.lb) != length(ci.ub))
@@ -483,10 +481,9 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       if (length(olim) != 2L)
          stop(mstyle$stop("Argument 'olim' must be of length 2."))
       olim <- sort(olim)
-      yi[yi < olim[1]] <- olim[1]
-      yi[yi > olim[2]] <- olim[2]
-      ci.lb[ci.lb < olim[1]] <- olim[1]
-      ci.ub[ci.ub > olim[2]] <- olim[2]
+      yi    <- .applyolim(yi, olim)
+      ci.lb <- .applyolim(ci.lb, olim)
+      ci.ub <- .applyolim(ci.ub, olim)
    }
 
    if (showweights) {                           # inverse variance weights after ordering/subsetting and
@@ -570,16 +567,24 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    ### x-axis labels (apply transformation to axis labels if requested)
 
-   at.lab <- at
+   if (is.null(ddd$at.lab)) {
 
-   if (is.function(atransf)) {
-      if (is.null(targs)) {
-         at.lab <- fmtx(sapply(at.lab, atransf), digits[[2]], drop0ifint=TRUE)
+      at.lab <- at
+
+      if (is.function(atransf)) {
+         if (is.null(targs)) {
+            at.lab <- fmtx(sapply(at.lab, atransf), digits[[2]], drop0ifint=TRUE)
+         } else {
+            at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[2]], drop0ifint=TRUE)
+         }
       } else {
-         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[2]], drop0ifint=TRUE)
+         at.lab <- fmtx(at.lab, digits[[2]], drop0ifint=TRUE)
       }
+
    } else {
-      at.lab <- fmtx(at.lab, digits[[2]], drop0ifint=TRUE)
+
+      at.lab <- ddd$at.lab
+
    }
 
    ### set plot limits (xlim)
@@ -616,7 +621,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    plot.multp.r <- area.anno / area.forest
 
    if (missing(xlim)) {
-      if (min(ci.ub, na.rm=TRUE) < alim[1]) {
+      if (min(ci.lb, na.rm=TRUE) < alim[1]) {
          f.1 <- alim[1]
       } else {
          f.1 <- min(ci.lb, na.rm=TRUE)
@@ -652,11 +657,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    ### allow adjustment of position of study labels and annotations via textpos argument
 
-   if (is.null(ddd$textpos)) {
-      textpos <- xlim
-   } else {
-      textpos <- ddd$textpos
-   }
+   textpos <- .chkddd(ddd$textpos, xlim)
 
    if (length(textpos) != 2L)
       stop(mstyle$stop("Argument 'textpos' must be of length 2."))
@@ -672,7 +673,11 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (missing(ylim)) {
       ylim <- c(0.5, max(rows, na.rm=TRUE)+top)
    } else {
-      ylim <- sort(ylim)
+      if (length(ylim) == 1L) {
+         ylim <- c(ylim, max(rows, na.rm=TRUE)+top)
+      } else {
+         ylim <- sort(ylim)
+      }
    }
 
    #########################################################################
@@ -885,8 +890,6 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          annotext <- fmtx(annotext, digits[[1]])
       }
 
-      annotext <- sub("-", annosym[4], annotext, fixed=TRUE)
-
       if (missing(width)) {
          width <- apply(annotext, 2, function(x) max(nchar(x)))
       } else {
@@ -901,13 +904,16 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       }
 
       if (showweights) {
-         annotext <- cbind(annotext[,1], "%   ", annotext[,2], annosym[1], annotext[,3], annosym[2], annotext[,4], annosym[3])
+         annotext <- cbind(annotext[,1], paste0("%", paste0(rep(substr(annosym[1],1,1),3), collapse="")), annotext[,2], annosym[1], annotext[,3], annosym[2], annotext[,4], annosym[3])
       } else {
          annotext <- cbind(annotext[,1], annosym[1], annotext[,2], annosym[2], annotext[,3], annosym[3])
       }
 
       annotext <- apply(annotext, 1, paste, collapse="")
       annotext[grepl("NA", annotext, fixed=TRUE)] <- ""
+      annotext <- gsub("-", annosym[4], annotext, fixed=TRUE) # [a]
+      annotext <- gsub(" ", annosym[5], annotext, fixed=TRUE)
+
       par(family=names(fonts)[2], font=fonts[2])
       ltext(textpos[2], rows+rowadj[2], labels=annotext, pos=2, cex=cex, col=col, ...)
       par(family=names(fonts)[1], font=fonts[1])
