@@ -8,7 +8,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(x), must="rma", notav=c("rma.ls", "rma.gen"))
 
@@ -30,6 +30,8 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (is.function(transf) && is.function(atransf))
       stop(mstyle$stop("Use either 'transf' or 'atransf' to specify a transformation (not both)."))
 
+   .start.plot()
+
    if (missing(targs))
       targs <- NULL
 
@@ -68,13 +70,8 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       shade <- .getx("shade", mf=mf, data=x$data)
    }
 
-   if (missing(colshade)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         colshade <- "gray20"
-      } else {
-         colshade <- "gray90"
-      }
-   }
+   if (missing(colshade))
+      colshade <- .coladj(par("bg","fg"), dark=0.1, light=-0.1)
 
    if (missing(pch)) {
       pch <- 15
@@ -118,40 +115,29 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (x$int.only) {
 
       if (missing(col)) {
-         col <- c(par("fg"), "gray50") # 1st color for summary polygon, 2nd color for prediction interval line
+         col <- c(par("fg"), .coladj(par("fg"), dark=-0.3, light=0.3)) # 1st = summary polygon, 2nd = PI
       } else {
-         if (length(col) == 1L)        # if user only specified one value, assume it is for the summary polygon
-            col <- c(col, "gray50")
+         if (length(col) == 1L) # if user only specified one value, assume it is for the summary polygon
+            col <- c(col, .coladj(col, dark=-0.3, light=0.3))
       }
 
       if (missing(border))
-         border <- par("fg")           # border color of summary polygon
+         border <- par("fg") # border color of summary polygon
 
    } else {
 
-      if (missing(col)) {
-         if (is.element(par("bg"), c("black", "gray10"))) {
-            col <- "gray40"            # color of fitted values
-         } else {
-            col <- "gray"              # color of fitted values
-         }
-      }
+      if (missing(col))
+         col <- .coladj(par("bg","fg"), dark=0.2, light=-0.2) # color for fitted value polygons
 
-      if (missing(border)) {
-         if (is.element(par("bg"), c("black", "gray10"))) {
-            border <- "gray30"         # border color of fitted values
-         } else {
-            border <- "gray"           # border color of fitted values
-         }
-
-      }
+      if (missing(border))
+         border <- .coladj(par("bg","fg"), dark=0.3, light=-0.3)
 
    }
 
    ### set default line types if user has not specified 'lty' argument
 
    if (missing(lty)) {
-      lty <- c("solid", "dotted", "solid") # 1st value = CIs, 2nd value = prediction interval, 3rd = horizontal line(s)
+      lty <- c("solid", "dotted", "solid") # 1st = CIs, 2nd = PI, 3rd = horizontal line(s)
    } else {
       if (length(lty) == 1L)
          lty <- c(lty, "dotted", "solid")
@@ -159,26 +145,39 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          lty <- c(lty, "solid")
    }
 
-   ### vertical expansion factor: 1st = CI end lines, 2nd = arrows, 3rd = summary polygon or fitted polygons
+   ### vertical expansion factor: 1st = CI/PI end lines, 2nd = arrows, 3rd = summary polygon or fitted polygons
 
    if (length(efac) == 1L)
       efac <- rep(efac, 3L)
 
    if (length(efac) == 2L)
-      efac <- c(efac[1], efac[1], efac[2]) # if 2 values specified: 1st = CI end lines and arrows, 2nd = summary polygon or fitted polygons
+      efac <- c(efac[1], efac[1], efac[2]) # if 2 values specified: 1st = CI/PI end lines and arrows, 2nd = summary polygon or fitted polygons
+
+   efac[efac == 0] <- NA
 
    ### annotation symbols vector
 
    if (is.null(ddd$annosym)) {
-      annosym <- c(" [", ", ", "]", "-") # 4th element for minus sign symbol
+      annosym <- c(" [", ", ", "]", "-", " ") # 4th element for minus sign symbol; 5th for space (in place of numbers and +); see [a]
    } else {
       annosym <- ddd$annosym
       if (length(annosym) == 3L)
-         annosym <- c(annosym, "-")
-      if (length(annosym) != 4L)
-         stop(mstyle$stop("Argument 'annosym' must be a vector of length 3 (or 4)."))
+         annosym <- c(annosym, "-", " ")
+      if (length(annosym) == 4L)
+         annosym <- c(annosym, " ")
+      if (length(annosym) != 5L)
+         stop(mstyle$stop("Argument 'annosym' must be a vector of length 3 (or 4 or 5)."))
    }
 
+   ### adjust annosym for tabular figures
+
+   if (isTRUE(ddd$tabfig == 1))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2212", "\u2002") # \u2009 thin space; \u2212 minus, \u2002 en space
+   if (isTRUE(ddd$tabfig == 2))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2013", "\u2002") # \u2009 thin space; \u2013 en dash, \u2002 en space
+   if (isTRUE(ddd$tabfig == 3))
+      annosym <- c("\u2009[", ",\u2009", "]", "\u2212", "\u2007") # \u2009 thin space; \u2212 minus, \u2007 figure space
+
    ### get measure from object
 
    measure <- x$measure
@@ -216,17 +215,9 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    if (!is.null(ddd$addcred))
       addpred <- ddd$addcred
 
-   if (is.null(ddd$pi.type)) {
-      pi.type <- "default"
-   } else {
-      pi.type <- ddd$pi.type
-   }
+   pi.type <- .chkddd(ddd$pi.type, "default")
 
-   if (is.null(ddd$decreasing)) {
-      decreasing <- FALSE
-   } else {
-      decreasing <- ddd$decreasing
-   }
+   decreasing <- .chkddd(ddd$decreasing, FALSE)
 
    if (!is.null(ddd$clim))
       olim <- ddd$clim
@@ -243,11 +234,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          rowadj <- c(rowadj,0) # if two values are specified, use them for 1&2
    }
 
-   if (is.null(ddd$top)) {
-      top <- 3
-   } else {
-      top <- ddd$top
-   }
+   top <- .chkddd(ddd$top, 3)
 
    if (is.null(ddd$xlabadj)) {
       xlabadj <- c(NA,NA)
@@ -257,20 +244,16 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          xlabadj <- c(xlabadj, 1-xlabadj)
    }
 
-   if (is.null(ddd$xlabfont)) {
-      xlabfont <- 1
-   } else {
-      xlabfont <- ddd$xlabfont
-   }
+   xlabfont <- .chkddd(ddd$xlabfont, 1)
 
-   lplot     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) plot(...)
-   labline   <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) abline(...)
-   lsegments <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) segments(...)
-   laxis     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) axis(...)
-   lmtext    <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) mtext(...)
-   lpolygon  <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) polygon(...)
-   ltext     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) text(...)
-   lpoints   <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, top, xlabadj, xlabfont) points(...)
+   lplot     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) plot(...)
+   labline   <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) abline(...)
+   lsegments <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) segments(...)
+   laxis     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) axis(...)
+   lmtext    <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) mtext(...)
+   lpolygon  <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) polygon(...)
+   ltext     <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) text(...)
+   lpoints   <- function(..., textpos, addcred, pi.type, decreasing, clim, rowadj, annosym, tabfig, top, xlabadj, xlabfont, at.lab) points(...)
 
    if (is.character(showweights)) {
       weighttype  <- match.arg(showweights, c("diagonal", "rowsum"))
@@ -411,26 +394,26 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    options(na.action = "na.pass") # using na.pass to get the entire vector (length of yi.f)
 
-      if (x$int.only) {
-         pred <- fitted(x)
-         pred.ci.lb <- rep(NA_real_, k)
-         pred.ci.ub <- rep(NA_real_, k)
+   if (x$int.only) {
+      pred <- fitted(x)
+      pred.ci.lb <- rep(NA_real_, k)
+      pred.ci.ub <- rep(NA_real_, k)
+   } else {
+      temp <- predict(x, level=level, pi.type=pi.type)
+      pred <- temp$pred
+      if (addpred) {
+         pred.ci.lb <- temp$pi.lb
+         pred.ci.ub <- temp$pi.ub
       } else {
-         temp <- predict(x, level=level, pi.type=pi.type)
-         pred <- temp$pred
-         if (addpred) {
-            pred.ci.lb <- temp$pi.lb
-            pred.ci.ub <- temp$pi.ub
-         } else {
-            pred.ci.lb <- temp$ci.lb
-            pred.ci.ub <- temp$ci.ub
-         }
+         pred.ci.lb <- temp$ci.lb
+         pred.ci.ub <- temp$ci.ub
       }
+   }
 
-      weights <- try(weights(x, type=weighttype), silent=TRUE) # does not work for rma.glmm and rma.uni.selmodel objects
+   weights <- try(weights(x, type=weighttype), silent=TRUE) # does not work for rma.glmm and rma.uni.selmodel objects
 
-      if (inherits(weights, "try-error"))
-         weights <- rep(1, k)
+   if (inherits(weights, "try-error"))
+      weights <- rep(1, k)
 
    ### sort the data if requested
 
@@ -605,12 +588,12 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       if (length(olim) != 2L)
          stop(mstyle$stop("Argument 'olim' must be of length 2."))
       olim <- sort(olim)
-      yi[yi < olim[1]] <- olim[1]
-      yi[yi > olim[2]] <- olim[2]
-      ci.lb[ci.lb < olim[1]] <- olim[1]
-      ci.ub[ci.ub > olim[2]] <- olim[2]
-      pred.ci.lb[pred.ci.lb < olim[1]] <- olim[1]
-      pred.ci.ub[pred.ci.ub > olim[2]] <- olim[2]
+      yi         <- .applyolim(yi, olim)
+      ci.lb      <- .applyolim(ci.lb, olim)
+      ci.ub      <- .applyolim(ci.ub, olim)
+      pred       <- .applyolim(pred, olim)
+      pred.ci.lb <- .applyolim(pred.ci.lb, olim)
+      pred.ci.ub <- .applyolim(pred.ci.ub, olim)
    }
 
    ### set default point sizes (if not specified by user)
@@ -685,16 +668,24 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    ### x-axis labels (apply transformation to axis labels if requested)
 
-   at.lab <- at
+   if (is.null(ddd$at.lab)) {
 
-   if (is.function(atransf)) {
-      if (is.null(targs)) {
-         at.lab <- fmtx(sapply(at.lab, atransf), digits[[2]], drop0ifint=TRUE)
+      at.lab <- at
+
+      if (is.function(atransf)) {
+         if (is.null(targs)) {
+            at.lab <- fmtx(sapply(at.lab, atransf), digits[[2]], drop0ifint=TRUE)
+         } else {
+            at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[2]], drop0ifint=TRUE)
+         }
       } else {
-         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[2]], drop0ifint=TRUE)
+         at.lab <- fmtx(at.lab, digits[[2]], drop0ifint=TRUE)
       }
+
    } else {
-      at.lab <- fmtx(at.lab, digits[[2]], drop0ifint=TRUE)
+
+      at.lab <- ddd$at.lab
+
    }
 
    ### set plot limits (xlim)
@@ -731,7 +722,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
    plot.multp.r <- area.anno / area.forest
 
    if (missing(xlim)) {
-      if (min(ci.ub, na.rm=TRUE) < alim[1]) {
+      if (min(ci.lb, na.rm=TRUE) < alim[1]) {
          f.1 <- alim[1]
       } else {
          f.1 <- min(ci.lb, na.rm=TRUE)
@@ -767,11 +758,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    ### allow adjustment of position of study labels and annotations via textpos argument
 
-   if (is.null(ddd$textpos)) {
-      textpos <- xlim
-   } else {
-      textpos <- ddd$textpos
-   }
+   textpos <- .chkddd(ddd$textpos, xlim)
 
    if (length(textpos) != 2L)
       stop(mstyle$stop("Argument 'textpos' must be of length 2."))
@@ -791,7 +778,15 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          ylim <- c(0.5, max(rows, na.rm=TRUE)+top)
       }
    } else {
-      ylim <- sort(ylim)
+      if (length(ylim) == 1L) {
+         if (x$int.only && addfit) {
+            ylim <- c(ylim, max(rows, na.rm=TRUE)+top)
+         } else {
+            ylim <- c(ylim, max(rows, na.rm=TRUE)+top)
+         }
+      } else {
+         ylim <- sort(ylim)
+      }
    }
 
    #########################################################################
@@ -899,7 +894,9 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          if (is.na(pred[i]))
             next
 
-         lpolygon(x=c(max(pred.ci.lb[i], alim[1]), pred[i], min(pred.ci.ub[i], alim[2]), pred[i]), y=c(rows[i], rows[i]+(height/100)*cex*efac[3], rows[i], rows[i]-(height/100)*cex*efac[3]), col=col, border=border, ...)
+         lpolygon(x=c(max(pred.ci.lb[i], alim[1]), pred[i], min(pred.ci.ub[i], alim[2]), pred[i]),
+                  y=c(rows[i], rows[i]+(height/100)*cex*efac[3], rows[i], rows[i]-(height/100)*cex*efac[3]),
+                  col=col, border=border, ...)
 
          ### this would only draw intervals if bounds fall within alim range
          #if ((pred.ci.lb[i] > alim[1]) && (pred.ci.ub[i] < alim[2]))
@@ -918,12 +915,12 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       if (inherits(x, "rma.mv") && x$withG && x$tau2s > 1) {
 
          if (!is.logical(addpred)) {
-            ### for multiple tau^2 (and gamma^2) values, need to specify level(s) of the inner factor(s) to compute the prediction interval
+            ### for multiple tau^2 (and gamma^2) values, need to specify level(s) of the inner factor(s) to compute the PI
             ### this can be done via the addpred argument (i.e., instead of using a logical, one specifies the level(s))
             if (length(addpred) == 1L)
                addpred <- c(addpred, addpred)
             temp <- predict(x, level=level, tau2.levels=addpred[1], gamma2.levels=addpred[2], pi.type=pi.type)
-            addpred <- TRUE ### set addpred to TRUE, so if (!is.element(x$method, c("FE","EE","CE")) && addpred) further below works
+            addpred <- TRUE # set addpred to TRUE, so if (!is.element(x$method, c("FE","EE","CE")) && addpred) further below works
          } else {
             if (addpred) {
                ### here addpred=TRUE, but user has not specified the level, so throw an error
@@ -975,12 +972,11 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       ### apply observation/outcome limits if specified
 
       if (!missing(olim)) {
-         pred[pred < olim[1]] <- olim[1]
-         pred[pred > olim[2]] <- olim[2]
-         beta.ci.lb[beta.ci.lb < olim[1]] <- olim[1]
-         beta.ci.ub[beta.ci.ub > olim[2]] <- olim[2]
-         beta.pi.lb[beta.pi.lb < olim[1]] <- olim[1]
-         beta.pi.ub[beta.pi.ub > olim[2]] <- olim[2]
+         beta       <- .applyolim(beta, olim)
+         beta.ci.lb <- .applyolim(beta.ci.lb, olim)
+         beta.ci.ub <- .applyolim(beta.ci.ub, olim)
+         beta.pi.lb <- .applyolim(beta.pi.lb, olim)
+         beta.pi.ub <- .applyolim(beta.pi.ub, olim)
       }
 
       ### add prediction interval
@@ -1056,13 +1052,13 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
       ### if the lower bound is actually larger than upper x-axis limit, then everything is to the right and just draw a polygon pointing in that direction
       if (ci.lb[i] >= alim[2]) {
-         lpolygon(x=c(alim[2], alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], ...)
+         lpolygon(x=c(alim[2], alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], border=colout[i], ...)
          next
       }
 
       ### if the upper bound is actually lower than lower x-axis limit, then everything is to the left and just draw a polygon pointing in that direction
       if (ci.ub[i] <= alim[1]) {
-         lpolygon(x=c(alim[1], alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], ...)
+         lpolygon(x=c(alim[1], alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], border=colout[i], ...)
          next
       }
 
@@ -1071,13 +1067,13 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
       if (ci.lb[i] >= alim[1]) {
          lsegments(ci.lb[i], rows[i]-(height/150)*cex*efac[1], ci.lb[i], rows[i]+(height/150)*cex*efac[1], col=colout[i], ...)
       } else {
-         lpolygon(x=c(alim[1], alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], ...)
+         lpolygon(x=c(alim[1], alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]+(1.4/100)*cex*(xlim[2]-xlim[1]), alim[1]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], border=colout[i], ...)
       }
 
       if (ci.ub[i] <= alim[2]) {
          lsegments(ci.ub[i], rows[i]-(height/150)*cex*efac[1], ci.ub[i], rows[i]+(height/150)*cex*efac[1], col=colout[i], ...)
       } else {
-         lpolygon(x=c(alim[2], alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], ...)
+         lpolygon(x=c(alim[2], alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]-(1.4/100)*cex*(xlim[2]-xlim[1]), alim[2]), y=c(rows[i], rows[i]+(height/150)*cex*efac[2], rows[i]-(height/150)*cex*efac[2], rows[i]), col=colout[i], border=colout[i], ...)
       }
 
    }
@@ -1162,8 +1158,6 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          annotext <- fmtx(annotext, digits[[1]])
       }
 
-      annotext <- sub("-", annosym[4], annotext, fixed=TRUE)
-
       if (missing(width)) {
          width <- apply(annotext, 2, function(x) max(nchar(x)))
       } else {
@@ -1181,20 +1175,24 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
          width <- width[-1] # remove the first entry for the weights (so this can be used by addpoly() via .metafor)
 
       if (showweights) {
-         annotext <- cbind(annotext[,1], "%   ", annotext[,2], annosym[1], annotext[,3], annosym[2], annotext[,4], annosym[3])
+         annotext <- cbind(annotext[,1], paste0("%", paste0(rep(substr(annosym[1],1,1),3), collapse="")), annotext[,2], annosym[1], annotext[,3], annosym[2], annotext[,4], annosym[3])
       } else {
          annotext <- cbind(annotext[,1], annosym[1], annotext[,2], annosym[2], annotext[,3], annosym[3])
       }
 
       annotext <- apply(annotext, 1, paste, collapse="")
       annotext[grepl("NA", annotext, fixed=TRUE)] <- ""
+      annotext <- gsub("-", annosym[4], annotext, fixed=TRUE) # [a]
+      annotext <- gsub(" ", annosym[5], annotext, fixed=TRUE)
 
       par(family=names(fonts)[2], font=fonts[2])
+
       if (addfit && x$int.only) {
          ltext(textpos[2], c(rows,-1)+rowadj[2], labels=annotext, pos=2, cex=cex, ...)
       } else {
          ltext(textpos[2], rows+rowadj[2], labels=annotext, pos=2, cex=cex, ...)
       }
+
       par(family=names(fonts)[1], font=fonts[1])
 
    } else {
@@ -1234,7 +1232,7 @@ lty, fonts, cex, cex.lab, cex.axis, ...) {
 
    ### put stuff into the .metafor environment, so that it can be used by addpoly()
 
-   sav <- c(res, list(level=level, annotate=annotate, digits=digits[[1]], width=width, transf=transf, atransf=atransf, targs=targs, efac=efac[3], fonts=fonts[1:2], annosym=annosym))
+   sav <- c(res, list(level=level, annotate=annotate, digits=digits[[1]], width=width, transf=transf, atransf=atransf, targs=targs, efac=efac, fonts=fonts[1:2], annosym=annosym))
    try(assign("forest", sav, envir=.metafor), silent=TRUE)
 
    invisible(res)
