@@ -6,7 +6,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    na.act <- getOption("na.action")
 
@@ -23,29 +23,25 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    atransf.char <- deparse(atransf)
 
-   if (missing(back)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         back <- "gray20"
-      } else {
-         back <- "lightgray"
-      }
-   }
+   if (anyNA(level) || is.null(level))
+      stop(mstyle$stop("Argument 'level' cannot be NA or NULL."))
 
-   if (missing(shade)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         shade <- "gray30"
-      } else {
-         shade <- "white"
-      }
-   }
+   .start.plot()
 
-   if (missing(hlines)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         hlines <- par("bg")
-      } else {
-         hlines <- "white"
-      }
-   }
+   if (missing(back))
+      back <- .coladj(par("bg","fg"), dark=0.1, light=-0.2)
+
+   if (missing(shade))
+      shade <- .coladj(par("bg","fg"), dark=c(0.2,-0.8), light=c(0,1))
+
+   if (length(level) > 1L && length(shade) == 1L)
+      shade <- rep(shade, length(level))
+
+   if (missing(hlines))
+      hlines <- .coladj(par("bg","fg"), dark=c(0,-0.9), light=c(0,1))
+
+   if (is.null(refline))
+      refline <- NA
 
    if (missing(pch))
       pch <- 19
@@ -63,7 +59,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       if (is.null(ni))
          ni <- attr(yi, "ni")
       if (!is.null(ni) && length(ni) != k)
-      stop(mstyle$stop(paste0("Length of the 'ni' argument (", length(ni), ") does not correspond to the number of outcomes (", k, ").")))
+         stop(mstyle$stop(paste0("Length of the 'ni' argument (", length(ni), ") does not correspond to the number of outcomes (", k, ").")))
       if (is.null(ni))
          stop(mstyle$stop("No sample size information available."))
    }
@@ -74,7 +70,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       vi <- NULL
 
    if (is.function(vi)) # if vi is utils::vi()
-      stop(mstyle$stop("Cannot find variable specified for 'vi' argument."), call.=FALSE)
+      stop(mstyle$stop("Cannot find variable specified for 'vi' argument."))
 
    if (missing(sei))
       sei <- NULL
@@ -197,13 +193,9 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
    if (length(col) != k)
       stop(mstyle$stop(paste0("Length of the 'col' argument (", length(col), ") does not correspond to the number of outcomes (", k, ").")))
 
-   if (missing(bg)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         bg <- "gray40"
-      } else {
-         bg <- "white"
-      }
-   }
+   if (missing(bg))
+      bg <- .coladj(par("bg","fg"), dark=0.1, light=-0.1)
+
    if (length(bg) == 1L) {
       bg.vec <- FALSE
       bg <- rep(bg, k)
@@ -221,61 +213,31 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
    if (!is.null(ddd$transf))
       warning("Function does not have a 'transf' argument (use 'atransf' instead).", call.=FALSE, immediate.=TRUE)
 
-   lplot     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) plot(...)
-   labline   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) abline(...)
-   lsegments <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) segments(...)
-   laxis     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) axis(...)
-   lpolygon  <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) polygon(...)
-   llines    <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) lines(...)
-   lpoints   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) points(...)
-   lrect     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) rect(...)
-   ltext     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) text(...)
+   lplot     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) plot(...)
+   labline   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) abline(...)
+   lsegments <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) segments(...)
+   laxis     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) axis(...)
+   lpolygon  <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) polygon(...)
+   llines    <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) lines(...)
+   lpoints   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) points(...)
+   lrect     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) rect(...)
+   ltext     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res, at.lab) text(...)
 
    ### refline2, level2, and lty2 for adding a second reference line / funnel
 
-   if (!is.null(ddd$refline2)) {
-      refline2 <- ddd$refline2
-   } else {
-      refline2 <- NULL
-   }
-
-   if (!is.null(ddd$level2)) {
-      level2 <- ddd$level2
-   } else {
-      level2 <- 95
-   }
-
-   if (!is.null(ddd$lty2)) {
-      lty2 <- ddd$lty2
-   } else {
-      lty2 <- 3
-   }
+   refline2 <- ddd$refline2
+   level2   <- .chkddd(ddd$level2, 95)
+   lty2     <- .chkddd(ddd$lty2, 3)
 
    ### number of y-axis values at which to calculate the bounds of the pseudo confidence interval
 
-   if (!is.null(ddd$ci.res)) {
-      ci.res <- ddd$ci.res
-   } else {
-      ci.res <- 1000
-   }
+   ci.res <- .chkddd(ddd$ci.res, 1000)
 
-   if (!is.null(ddd$colref)) {
-      colref <- ddd$colref
-   } else {
-      colref <- "black"
-   }
+   ### to adjust color of reference line, region bounds, and the L box
 
-   if (!is.null(ddd$colci)) {
-      colci <- ddd$colci
-   } else {
-      colci <- "black"
-   }
-
-   if (!is.null(ddd$colbox)) {
-      colbox <- ddd$colbox
-   } else {
-      colbox <- "black"
-   }
+   colref <- .chkddd(ddd$colref, .coladj(par("bg","fg"), dark=0.6, light=-0.6))
+   colci  <- .chkddd(ddd$colci,  .coladj(par("bg","fg"), dark=0.6, light=-0.6))
+   colbox <- .chkddd(ddd$colbox, .coladj(par("bg","fg"), dark=0.6, light=-0.6))
 
    #########################################################################
 
@@ -406,10 +368,9 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    if (is.element(yaxis, c("sei", "vi", "seinv", "vinv"))) {
 
-      level     <- ifelse(level == 0, 1, ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)))
-      level2    <- ifelse(level2 == 0, 1, ifelse(level2 >= 1, (100-level2)/100, ifelse(level2 > .5, 1-level2, level2)))
-      #level    <- ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)) # note: there may be multiple level values
-      level.min <- min(level)                                                              # note: smallest level is the widest CI
+      level  <- .level(level, allow.vector=TRUE) # note: there may be multiple level values
+      level2 <- .level(level2)
+      level.min <- min(level) # note: smallest level is the widest CI
       lvals     <- length(level)
 
       ### calculate the CI bounds at the bottom of the figure (for the widest CI if there are multiple)
@@ -432,7 +393,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       }
 
       if (missing(xlim)) {
-         xlim    <- c(min(x.lb.bot,min(yi)), max(x.ub.bot,max(yi))) # make sure x-axis not only includes widest CI, but also all yi values
+         xlim    <- c(min(x.lb.bot,min(yi),na.rm=TRUE), max(x.ub.bot,max(yi),na.rm=TRUE)) # make sure x-axis not only includes widest CI, but also all yi values
          rxlim   <- xlim[2] - xlim[1]        # calculate range of the x-axis limits
          xlim[1] <- xlim[1] - (rxlim * 0.10) # subtract 10% of range from lower x-axis bound
          xlim[2] <- xlim[2] + (rxlim * 0.10) # add      10% of range to   upper x-axis bound
@@ -598,11 +559,6 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    #########################################################################
 
-   ### add L-shaped box around plot
-
-   if (!is.na(colbox))
-      box(bty="l", col=colbox)
-
    ### generate x-axis positions if none are specified
 
    if (is.null(at)) {
@@ -614,22 +570,35 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       at <- at[at < par("usr")[2]]
    }
 
-   at.lab <- at
+   if (is.null(ddd$at.lab)) {
 
-   if (is.function(atransf)) {
-      if (is.null(targs)) {
-         at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
+      at.lab <- at
+
+      if (is.function(atransf)) {
+         if (is.null(targs)) {
+            at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
+         } else {
+            at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
+         }
       } else {
-         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
+         at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
       }
+
    } else {
-      at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
+
+      at.lab <- ddd$at.lab
+
    }
 
    ### add x-axis
 
    laxis(side=1, at=at, labels=at.lab, ...)
 
+   ### add L-shaped box around plot
+
+   if (!is.na(colbox))
+      box(bty="l", col=colbox)
+
    ############################################################################
 
    ### labeling of points
@@ -638,6 +607,9 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    if (is.numeric(label) || is.character(label) || .isTRUE(label)) {
 
+      if (is.na(refline))
+         refline <- mean(yi, na.rm=TRUE)
+
       if (is.numeric(label)) {
          label <- round(label)
          if (label < 0)
@@ -666,64 +638,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    ### add legend (if requested)
 
-   if (is.logical(legend) && isTRUE(legend))
-      lpos <- "topright"
-
-   if (is.character(legend)) {
-      lpos <- legend
-      legend <- TRUE
-   }
-
-   if (legend && !is.element(yaxis, c("sei", "vi", "seinv", "vinv"))) {
-      legend <- FALSE
-      warning(mstyle$warning("Argument 'legend' only applicable if 'yaxis' is 'sei', 'vi', 'seinv', or 'vinv'."), call.=FALSE)
-   }
-
-   if (legend) {
-
-      level <- c(level, 0)
-      lvals <- length(level)
-
-      add.studies <- !pch.vec && !col.vec && !bg.vec # only add 'Studies' to legend if pch, col, and bg were not vectors to begin with
-
-      scipen <- options(scipen=100)
-      lchars <- max(nchar(level))-2
-      options(scipen=scipen$scipen)
-
-      pval1 <- NULL
-      pval2 <- NULL
-      phantom <- NULL
-
-      ltxt <- sapply(seq_len(lvals), function(i) {
-         if (i == 1)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=fmtx(level[i], lchars), pval2=fmtx(1, lchars)))))
-            #return(as.expression(bquote(p > .(pval), list(pval=fmtx(level[i], lchars)))))
-         if (i > 1 && i < lvals)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=fmtx(level[i], lchars), pval2=fmtx(level[i-1], lchars)))))
-         if (i == lvals)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=fmtx(0, lchars), pval2=fmtx(level[i-1], lchars)))))
-      })
-
-      pch.l  <- rep(22, lvals)
-      col.l  <- rep("black", lvals)
-      pt.cex <- rep(2, lvals)
-      pt.bg  <- c(shade, back)
-
-      if (add.studies) {
-         ltxt   <- c(ltxt, expression(plain(Studies)))
-         pch.l  <- c(pch.l, pch[1])
-         col.l  <- c(col.l, col[1])
-         pt.cex <- c(pt.cex, 1)
-         pt.bg  <- c(pt.bg, bg[1])
-      }
-
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         legend(lpos, inset=.01, bg="gray10", pch=pch.l, col=col.l, pt.cex=pt.cex, pt.bg=pt.bg, legend=ltxt)
-      } else {
-         legend(lpos, inset=.01, bg="white", pch=pch.l, col=col.l, pt.cex=pt.cex, pt.bg=pt.bg, legend=ltxt)
-      }
-
-   }
+   .funnel.legend(legend, level, shade, back, yaxis, trimfill=FALSE, pch, col, bg, pch.fill=NA, pch.vec, col.vec, bg.vec, colci)
 
    ############################################################################
 
