@@ -1,9 +1,15 @@
 logLik.rma <- function(object, REML, ...) {
 
-   if (!inherits(object, "rma"))
-      stop("Argument 'object' must be an object of class \"rma\".")
+   mstyle <- .get.mstyle()
 
-   if (missing(REML)) {
+   .chkclass(class(object), must="rma")
+
+   # in case something like logLik(res1, res2) is used
+
+   if (!missing(REML) && inherits(REML, "rma"))
+      REML <- NULL
+
+   if (missing(REML) || is.null(REML)) {
       if (object$method == "REML") {
          REML <- TRUE
       } else {
