@@ -4,9 +4,9 @@
 ### Liao, J. G. & Rosen, O. (2001). Fast and stable algorithms for computing and sampling from the
 ### noncentral hypergeometric distribution. The American Statistician, 55, 366-369.
 
-.dnoncenhypergeom <- function (x=NA, n1, n2, m1, psi) { ### x=ai, n1=ai+bi, n2=ci+di, m1=ai+ci, psi=ORi
+.dnoncenhypergeom <- function (x=NA_real_, n1, n2, m1, psi) { # x=ai, n1=ai+bi, n2=ci+di, m1=ai+ci, psi=ORi
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    mode.compute <- function(n1, n2, m1, psi, ll, uu) {
       a <- psi - 1
@@ -26,19 +26,19 @@
    uu <- min(n1, m1)
 
    if (n1 < 0 | n2 < 0)
-      stop(mstyle$stop("'n1' or 'n2' negative in dnoncenhypergeom()."))
+      stop(mstyle$stop("'n1' or 'n2' negative in dnoncenhypergeom()."), call.=FALSE)
 
    if (m1 < 0 | m1 > (n1 + n2))
       stop(mstyle$stop("'m1' out of range in dnoncenhypergeom()."))
 
    if (psi <= 0)
-      stop(mstyle$stop("'psi' [odds ratio] negative in dnoncenhypergeom()."))
+      stop(mstyle$stop("'psi' [odds ratio] negative in dnoncenhypergeom()."), call.=FALSE)
 
    if (!is.na(x) & (x < ll | x > uu))
       stop(mstyle$stop("'x' out of bounds in dnoncenhypergeom()."))
 
    if (!is.na(x) & length(x) > 1L)
-      stop(mstyle$stop("'x' neither missing or scalar in dnoncenhypergeom()."))
+      stop(mstyle$stop("'x' neither missing or scalar in dnoncenhypergeom()."), call.=FALSE)
 
    mode <- mode.compute(n1, n2, m1, psi, ll, uu)
    pi <- array(1, uu - ll + 1)
@@ -67,7 +67,7 @@
 
 .dnchgi <- function(logOR, ai, bi, ci, di, mu.i, tau2, random, dnchgcalc, dnchgprec) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    k <- length(logOR)
    dnchgi <- rep(NA_real_, k)
@@ -110,12 +110,12 @@
 
 .dnchg <- function(parms, ai, bi, ci, di, X.fit, random, verbose=FALSE, digits, dnchgcalc, dnchgprec, intCtrl) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    p    <- ncol(X.fit)
    k    <- length(ai)
-   beta <- parms[seq_len(p)]                  ### first p elemenets in parms are the model coefficients
-   tau2 <- ifelse(random, exp(parms[p+1]), 0) ### next value is tau^2 -- optimize over exp(tau^2) value or hold at 0 if random=FALSE
+   beta <- parms[seq_len(p)]                  # first p elemenets in parms are the model coefficients
+   tau2 <- ifelse(random, exp(parms[p+1]), 0) # next value is tau^2 -- optimize over exp(tau^2) value or hold at 0 if random=FALSE
    mu.i <- X.fit %*% cbind(beta)
 
    lli  <- rep(NA_real_, k)
@@ -127,7 +127,7 @@
       }
 
       if (verbose)
-         cat(mstyle$verbose(paste("ll =", .fcf(sum(lli), digits[["fit"]]), " ", .fcf(beta, digits[["est"]]), "\n")))
+         cat(mstyle$verbose(paste("ll =", fmtx(sum(lli), digits[["fit"]]), " ", fmtx(beta, digits[["est"]]), "\n")))
 
    }
 
@@ -150,7 +150,7 @@
       }
 
       if (verbose)
-         cat(mstyle$verbose(paste("ll = ", .fcf(sum(lli), digits[["fit"]]), " ", .fcf(tau2, digits[["var"]]), " ", .fcf(beta, digits[["est"]]), "\n")))
+         cat(mstyle$verbose(paste("ll = ", fmtx(sum(lli), digits[["fit"]]), " ", fmtx(tau2, digits[["var"]]), " ", fmtx(beta, digits[["est"]]), "\n")))
 
    }
 
