@@ -25,9 +25,38 @@
 
 ############################################################################
 
+### function to check vccon elements
+
+.chkvccon <- function(ids, vcvals) {
+
+   # get name of vcvals
+
+   vcname <- as.character(match.call()[[3]])
+
+   if (is.null(ids) || is.null(vcvals))
+      return(vcvals)
+
+   if (length(ids) != length(vcvals)) {
+      mstyle <- .get.mstyle()
+      stop(mstyle$stop(paste0("Length of 'vccon$", vcname, "' (", length(ids), ") does not match length of ", vcname, " (", length(vcvals), ").")), call.=FALSE)
+   }
+
+   for (id in unique(ids))
+      vcvals[ids == id] <- mean(vcvals[ids == id], na.rm=TRUE)
+
+   # if all elements are NA, then the mean will be NaN, so fix this back to NA
+
+   vcvals[is.nan(vcvals)] <- NA_real_
+
+   return(vcvals)
+
+}
+
+############################################################################
+
 .process.G.aftersub <- function(mf.g, struct, formula, tau2, rho, isG, k, sparse, verbose) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (verbose > 1)
       message(mstyle$message(paste0("Processing '", paste0(formula, collapse=""), "' term (#1) ...")))
@@ -38,12 +67,14 @@
 
    ### check that the number of variables is correct for the chosen structure
 
-   if (is.element(struct, c("CS","HCS","UN","UNR","AR","HAR","CAR","ID","DIAG","PHYBM","PHYPL","PHYPD")) && nvars != 2)
+   if (is.element(struct, c("CS","HCS","UN","UNR","AR","HAR","CAR","ID","DIAG","PHYBM","PHYPL","PHYPD")) && sum(sapply(mf.g, NCOL)) != 2)
       stop(mstyle$stop(paste0("Only a single inner variable allowed for an '~ inner | outer' term when 'struct=\"", struct, "\"'.")), call.=FALSE)
 
+   # note: need to use sum(sapply(mf.g, NCOL)) above because when 'random = ~ X | study' (and X is a matrix with 2+ columns), nvars will still be 2 for (unless struct="GEN")
+
    ### get variables names in mf.g
 
-   g.names <- names(mf.g) ### names for inner and outer factors/variables
+   g.names <- names(mf.g) # names for inner and outer factors/variables
 
    ### check that inner variable is a factor (or character variable) for structures that require this (no longer required)
 
@@ -55,7 +86,7 @@
    if (is.element(struct, c("CAR"))) {
       if (!is.numeric(mf.g[[1]]))
          stop(mstyle$stop("Inner variable in '~ inner | outer' term must be numeric for 'struct=\"CAR\"'."), call.=FALSE)
-      g.values <- sort(unique(round(mf.g[[1]], digits=8))) ### aweful hack to avoid floating points issues
+      g.values <- sort(unique(round(mf.g[[1]], digits=8L))) # aweful hack to avoid floating points issues
    } else {
       g.values <- NULL
    }
@@ -76,7 +107,7 @@
 
    ### get number of levels of each variable in mf.g (vector with two values, for the inner and outer factor)
 
-   #g.nlevels <- c(nlevels(mf.g[[1]]), nlevels(mf.g[[2]])) ### works only for factors
+   #g.nlevels <- c(nlevels(mf.g[[1]]), nlevels(mf.g[[2]])) # works only for factors
    if (is.element(struct, c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD","GEN","GDIAG"))) {
       g.nlevels <- c(length(unique(apply(mf.g[-nvars], 1, paste, collapse=" + "))), length(unique(mf.g[[nvars]])))
    } else {
@@ -85,7 +116,7 @@
 
    ### get levels of each variable in mf.g
 
-   #g.levels <- list(levels(mf.g[[1]]), levels(mf.g[[2]])) ### works only for factors
+   #g.levels <- list(levels(mf.g[[1]]), levels(mf.g[[2]])) # works only for factors
    if (is.element(struct, c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD","GEN","GDIAG"))) {
       g.levels <- list(sort(unique(apply(mf.g[-nvars], 1, paste, collapse=" + "))), sort(unique((mf.g[[nvars]]))))
    } else {
@@ -223,7 +254,7 @@
 
 .process.G.afterrmna <- function(mf.g, g.nlevels, g.levels, g.values, struct, formula, tau2, rho, Z.G1, Z.G2, isG, sparse, distspec, verbose) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (verbose > 1)
       message(mstyle$message(paste0("Processing '", paste0(formula, collapse=""), "' term (#2) ...")))
@@ -248,7 +279,7 @@
 
    ### redo: get number of levels of each variable in mf.g (vector with two values, for the inner and outer factor)
 
-   #g.nlevels <- c(nlevels(mf.g[[1]]), nlevels(mf.g[[2]])) ### works only for factors
+   #g.nlevels <- c(nlevels(mf.g[[1]]), nlevels(mf.g[[2]])) # works only for factors
    if (is.element(struct, c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD","GEN","GDIAG"))) {
       g.nlevels <- c(length(unique(apply(mf.g[-nvars], 1, paste, collapse=" + "))), length(unique(mf.g[[nvars]])))
    } else {
@@ -257,7 +288,7 @@
 
    ### redo: get levels of each variable in mf.g
 
-   #g.levels <- list(levels(mf.g[[1]]), levels(mf.g[[2]])) ### works only for factors
+   #g.levels <- list(levels(mf.g[[1]]), levels(mf.g[[2]])) # works only for factors
    if (is.element(struct, c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD","GEN","GDIAG"))) {
       g.levels <- list(sort(unique(apply(mf.g[-nvars], 1, paste, collapse=" + "))), sort(unique((mf.g[[nvars]]))))
    } else {
@@ -441,22 +472,22 @@
 
       ### create distance matrix
 
-      if (is.matrix(distspec)) {
+      if (.is.matrix(distspec)) {
 
          if (anyNA(distspec))
-            stop(mstyle$stop("No missing values allowed in matrices specified via 'dist'."))
+            stop(mstyle$stop("No missing values allowed in matrices specified via 'dist'."), call.=FALSE)
          if (!.is.square(distspec))
-            stop(mstyle$stop("Distance matrices specified via 'dist' must be square matrices."))
+            stop(mstyle$stop("Distance matrices specified via 'dist' must be square matrices."), call.=FALSE)
          if (!isSymmetric(unname(distspec)))
-            stop(mstyle$stop("Distance matrices specified via 'dist' must be symmetric matrices."))
+            stop(mstyle$stop("Distance matrices specified via 'dist' must be symmetric matrices."), call.=FALSE)
          if (is.null(rownames(distspec)))
             rownames(distspec) <- colnames(distspec)
          if (is.null(colnames(distspec)))
             colnames(distspec) <- rownames(distspec)
          if (length(colnames(distspec)) != length(unique(colnames(distspec))))
-            stop(mstyle$stop("Distance matrices specified via 'dist' must have unique dimension names."))
+            stop(mstyle$stop("Distance matrices specified via 'dist' must have unique dimension names."), call.=FALSE)
          if (any(!is.element(as.character(mf.g[[1]]), colnames(distspec))))
-            stop(mstyle$stop(paste0("There are levels in '", colnames(mf.g)[1], "' for which there are no matching rows/columns in the corresponding 'dist' matrix.")))
+            stop(mstyle$stop(paste0("There are levels in '", colnames(mf.g)[1], "' for which there are no matching rows/columns in the corresponding 'dist' matrix.")), call.=FALSE)
 
          if (is.element(struct, c("PHYBM","PHYPL","PHYPD")) && !all.equal(min(distspec), 0))
             warning(mstyle$warning("Minimum value in the distance matrix is not 0."), call.=FALSE)
@@ -469,7 +500,7 @@
       } else {
 
          if (is.element(struct, c("PHYBM","PHYPL","PHYPD")))
-            stop(mstyle$stop("Must supply distance matrix via 'dist' for phylogenetic correlation structures."))
+            stop(mstyle$stop("Must supply distance matrix via 'dist' for phylogenetic correlation structures."), call.=FALSE)
 
          Cmat <- model.matrix(formula, data=mf.g[-nvars])
 
@@ -582,7 +613,7 @@
    if (any(g.levels.r) && struct == "UNR") {
       G[g.levels.r,] <- 0
       G[,g.levels.r] <- 0
-      diag(G) <- tau2 ### don't really need this
+      diag(G) <- tau2 # don't really need this
       rho <- G[lower.tri(G)]
       warning(mstyle$warning(paste0("Fixed ", ifelse(isG, 'rho', 'phi'), " value(s) to 0 for removed level(s).")), call.=FALSE)
    }
@@ -631,7 +662,7 @@
    G <- matrix(0, nrow=dims, ncol=dims)
    G[lower.tri(G)] <- covs
    diag(G) <- vars
-   return(crossprod(G))
+   return(tcrossprod(G))
 }
 
 ### function to construct var-cov matrix for "UNR" structure given the variance and correlations
@@ -651,30 +682,30 @@
    G <- matrix(0, nrow=dims, ncol=dims)
    G[lower.tri(G)] <- cors
    diag(G) <- 1
-   return(var * crossprod(G))
+   return(var * tcrossprod(G))
 }
 
 ############################################################################
 
 ### function to construct var-cov matrix (G or H) for '~ inner | outer' terms
 
-.con.E <- function(v, r, v.val, r.val, Z1, Z2, levels.r, values, Dmat, struct, cholesky, vctransf, vccov, nearpd, sparse) {
+.con.E <- function(v, r, v.arg, r.arg, Z1, Z2, levels.r, values, Dmat, struct, cholesky, vctransf, vccov, nearpd, sparse) {
 
    ### if cholesky=TRUE, back-transformation/substitution is done below; otherwise, back-transform and replace fixed values
 
    if (!cholesky) {
       if (vctransf) {
-         v <- ifelse(is.na(v.val), exp(v), v.val)           ### variances are optimized in log space, so exponentiate
+         v <- ifelse(is.na(v.arg), exp(v), v.arg)           # variances are optimized in log space, so exponentiate
          if (struct == "CAR")
-            r <- ifelse(is.na(r.val), plogis(r), r.val)     ### CAR correlation is optimized in qlogis space, so use plogis
+            r <- ifelse(is.na(r.arg), plogis(r), r.arg)     # CAR correlation is optimized in qlogis space, so use plogis
          if (is.element(struct, c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD")))
-            r <- ifelse(is.na(r.val), exp(r), r.val)        ### spatial and phylogenetic 'correlation' parameter is optimized in log space, so exponentiate
+            r <- ifelse(is.na(r.arg), exp(r), r.arg)        # spatial and phylogenetic 'correlation' parameter is optimized in log space, so exponentiate
          if (!is.element(struct, c("CAR","SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD")))
-            r <- ifelse(is.na(r.val), tanh(r), r.val)       ### other correlations are optimized in atanh space, so use tanh
+            r <- ifelse(is.na(r.arg), tanh(r), r.arg)       # other correlations are optimized in atanh space, so use tanh
       } else {
          ### for Hessian computation, can choose to leave as is
-         v <- ifelse(is.na(v.val), v, v.val)
-         r <- ifelse(is.na(r.val), r, r.val)
+         v <- ifelse(is.na(v.arg), v, v.arg)
+         r <- ifelse(is.na(r.arg), r, r.arg)
          v[v < 0] <- 0
          if (struct == "CAR") {
             r[r < 0] <- 0
@@ -685,10 +716,10 @@
          }
          if (!is.element(struct, c("CAR","SPEXP","SPGAU","SPLIN","SPRAT","SPSPH","PHYBM","PHYPL","PHYPD")) && !vccov) {
             r[r < -1] <- -1
-            r[r > 1] <- 1
+            r[r >  1] <-  1
          }
       }
-      v <- ifelse(v <= .Machine$double.eps*10, 0, v) ### don't do this with Cholesky factorization, since values can be negative
+      v <- ifelse(v <= .Machine$double.eps*10, 0, v) # don't do this with Cholesky factorization, since values can be negative
    }
 
    ncol.Z1 <- ncol(Z1)
@@ -708,32 +739,32 @@
    if (is.element(struct, c("UN","GEN"))) {
       if (cholesky) {
          E <- .con.vcov.UN.chol(v, r)
-         v <- diag(E)                  ### need this, so correct values are shown when verbose=TRUE
-         r <- cov2cor(E)[lower.tri(E)] ### need this, so correct values are shown when verbose=TRUE
-         v[!is.na(v.val)] <- v.val[!is.na(v.val)] ### replace any fixed values
-         r[!is.na(r.val)] <- r.val[!is.na(r.val)] ### replace any fixed values
+         v <- diag(E)                  # need this, so correct values are shown when verbose=TRUE
+         r <- cov2cor(E)[lower.tri(E)] # need this, so correct values are shown when verbose=TRUE
+         v[!is.na(v.arg)] <- v.arg[!is.na(v.arg)] # replace any fixed values
+         r[!is.na(r.arg)] <- r.arg[!is.na(r.arg)] # replace any fixed values
       }
       E <- .con.vcov.UN(v, r, vccov)
       if (nearpd) {
-         E <- as.matrix(nearPD(E)$mat) ### nearPD() in Matrix package
-         v <- diag(E)                  ### need this, so correct values are shown when verbose=TRUE
-         r <- cov2cor(E)[lower.tri(E)] ### need this, so correct values are shown when verbose=TRUE
+         E <- as.matrix(nearPD(E)$mat) # nearPD() in Matrix package
+         v <- diag(E)                  # need this, so correct values are shown when verbose=TRUE
+         r <- cov2cor(E)[lower.tri(E)] # need this, so correct values are shown when verbose=TRUE
       }
    }
 
    if (struct == "UNR") {
       if (cholesky) {
          E <- .con.vcov.UNR.chol(v, r)
-         v <- diag(E)[1,1]             ### need this, so correct values are shown when verbose=TRUE
-         r <- cov2cor(E)[lower.tri(E)] ### need this, so correct values are shown when verbose=TRUE
-         v[!is.na(v.val)] <- v.val[!is.na(v.val)] ### replace any fixed values
-         r[!is.na(r.val)] <- r.val[!is.na(r.val)] ### replace any fixed values
+         v <- diag(E)[1,1]             # need this, so correct values are shown when verbose=TRUE
+         r <- cov2cor(E)[lower.tri(E)] # need this, so correct values are shown when verbose=TRUE
+         v[!is.na(v.arg)] <- v.arg[!is.na(v.arg)] # replace any fixed values
+         r[!is.na(r.arg)] <- r.arg[!is.na(r.arg)] # replace any fixed values
       }
       E <- .con.vcov.UNR(v, r)
       if (nearpd) {
-         E <- as.matrix(nearPD(E, keepDiag=TRUE)$mat) ### nearPD() in Matrix package
-         v <- E[1,1]                   ### need this, so correct values are shown when verbose=TRUE
-         r <- cov2cor(E)[lower.tri(E)] ### need this, so correct values are shown when verbose=TRUE
+         E <- as.matrix(nearPD(E, keepDiag=TRUE)$mat) # nearPD() in Matrix package
+         v <- E[1,1]                   # need this, so correct values are shown when verbose=TRUE
+         r <- cov2cor(E)[lower.tri(E)] # need this, so correct values are shown when verbose=TRUE
       }
    }
 
@@ -823,27 +854,29 @@
 
 ############################################################################
 
-### -1 times the log likelihood (regular or restricted) for rma.mv models
+### -1 times the log-likelihood (regular or restricted) for rma.mv models
 
-.ll.rma.mv <- function(par, reml, Y, M, A, X.fit, k, pX, # note: X.fit due to hessian(); pX due to nlm(); M=V to begin with
+.ll.rma.mv <- function(par, reml, Y, M, A, X, k, pX, # note: pX due to nlm(); M=V to begin with
                        D.S, Z.G1, Z.G2, Z.H1, Z.H2, g.Dmat, h.Dmat,
-                       sigma2.val, tau2.val, rho.val, gamma2.val, phi.val,
+                       sigma2.arg, tau2.arg, rho.arg, gamma2.arg, phi.arg, beta.arg,
                        sigma2s, tau2s, rhos, gamma2s, phis,
                        withS, withG, withH,
                        struct, g.levels.r, h.levels.r, g.values, h.values,
-                       sparse, cholesky, nearpd, vctransf, vccov,
+                       sparse, cholesky, nearpd, vctransf, vccov, vccon,
                        verbose, digits, REMLf, dofit=FALSE, hessian=FALSE) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
-   ### only NA values in sigma2.val, tau2.val, rho.val, gamma2.val, phi.val should be estimated; otherwise, replace with fixed values
+   ### only NA values in sigma2.arg, tau2.arg, rho.arg, gamma2.arg, phi.arg should be estimated; otherwise, replace with fixed values
 
    if (withS) {
 
+      vars <- par[seq_len(sigma2s)]
+
       if (vctransf) {
-         sigma2 <- ifelse(is.na(sigma2.val), exp(par[seq_len(sigma2s)]), sigma2.val) ### sigma2 is optimized in log space, so exponentiate
+         sigma2 <- ifelse(is.na(sigma2.arg), exp(vars), sigma2.arg) # sigma2 is optimized in log space, so exponentiate
       } else {
-         sigma2 <- ifelse(is.na(sigma2.val), par[seq_len(sigma2s)], sigma2.val)      ### for Hessian computation, can choose to leave as is
+         sigma2 <- ifelse(is.na(sigma2.arg), vars, sigma2.arg)      # for Hessian computation, can choose to leave as is
          sigma2[sigma2 < 0] <- 0
       }
 
@@ -853,6 +886,11 @@
       ### set really small sigma2 values equal to 0 (anything below .Machine$double.eps*10 is essentially 0)
       sigma2 <- ifelse(sigma2 <= .Machine$double.eps*10, 0, sigma2)
 
+      if (!is.null(vccon) && !is.null(vccon$sigma2)) {
+         for (id in unique(vccon$sigma2))
+            sigma2[vccon$sigma2 == id] <- mean(sigma2[vccon$sigma2 == id])
+      }
+
       for (j in seq_len(sigma2s)) {
          M <- M + sigma2[j] * D.S[[j]]
       }
@@ -865,12 +903,34 @@
       cors <- par[(sigma2s+tau2s+1):(sigma2s+tau2s+rhos)]
 
       resG <- .con.E(v=vars, r=cors,
-                     v.val=tau2.val, r.val=rho.val, Z1=Z.G1, Z2=Z.G2, levels.r=g.levels.r, values=g.values, Dmat=g.Dmat,
+                     v.arg=tau2.arg, r.arg=rho.arg, Z1=Z.G1, Z2=Z.G2, levels.r=g.levels.r, values=g.values, Dmat=g.Dmat,
                      struct=struct[1], cholesky=cholesky[1], vctransf=vctransf, vccov=vccov, nearpd=nearpd, sparse=sparse)
       tau2 <- resG$v
       rho  <- resG$r
       G    <- resG$E
 
+      if (!is.null(vccon)) {
+
+         if (!is.null(vccon$tau2)) {
+            for (id in unique(vccon$tau2))
+               tau2[vccon$tau2 == id] <- mean(tau2[vccon$tau2 == id])
+         }
+
+         if (!is.null(vccon$rho)) {
+            for (id in unique(vccon$rho)) {
+               rho[vccon$rho == id] <- mean(rho[vccon$rho == id])
+            }
+         }
+
+         resG <- .con.E(v=tau2, r=rho,
+                        v.arg=tau2.arg, r.arg=rho.arg, Z1=Z.G1, Z2=Z.G2, levels.r=g.levels.r, values=g.values, Dmat=g.Dmat,
+                        struct=struct[1], cholesky=FALSE, vctransf=FALSE, vccov=vccov, nearpd=nearpd, sparse=sparse)
+         tau2 <- resG$v
+         rho  <- resG$r
+         G    <- resG$E
+
+      }
+
       M <- M + (Z.G1 %*% G %*% t(Z.G1)) * tcrossprod(Z.G2)
 
    }
@@ -881,12 +941,35 @@
       cors <- par[(sigma2s+tau2s+rhos+gamma2s+1):(sigma2s+tau2s+rhos+gamma2s+phis)]
 
       resH <- .con.E(v=vars, r=cors,
-                     v.val=gamma2.val, r.val=phi.val, Z1=Z.H1, Z2=Z.H2, levels.r=h.levels.r, values=h.values, Dmat=h.Dmat,
+                     v.arg=gamma2.arg, r.arg=phi.arg, Z1=Z.H1, Z2=Z.H2, levels.r=h.levels.r, values=h.values, Dmat=h.Dmat,
                      struct=struct[2], cholesky=cholesky[2], vctransf=vctransf, vccov=vccov, nearpd=nearpd, sparse=sparse)
       gamma2 <- resH$v
       phi    <- resH$r
       H      <- resH$E
 
+      if (!is.null(vccon)) {
+
+         if (!is.null(vccon$gamma2)) {
+            for (id in unique(vccon$gamma2)) {
+               gamma2[vccon$gamma2 == id] <- mean(gamma2[vccon$gamma2 == id])
+            }
+         }
+
+         if (!is.null(vccon$phi)) {
+            for (id in unique(vccon$phi)) {
+               phi[vccon$phi == id] <- mean(phi[vccon$phi == id])
+            }
+         }
+
+         resH <- .con.E(v=gamma2, r=phi,
+                        v.arg=gamma2.arg, r.arg=phi.arg, Z1=Z.H1, Z2=Z.H2, levels.r=h.levels.r, values=h.values, Dmat=h.Dmat,
+                        struct=struct[2], cholesky=FALSE, vctransf=FALSE, vccov=vccov, nearpd=nearpd, sparse=sparse)
+         gamma2 <- resH$v
+         phi    <- resH$r
+         H      <- resH$E
+
+      }
+
       M <- M + (Z.H1 %*% H %*% t(Z.H1)) * tcrossprod(Z.H2)
 
    }
@@ -917,12 +1000,12 @@
 
    if (inherits(W, "try-error")) {
 
-      ### if M is not positive-definite, set the (restricted) log likelihood to -Inf
+      ### if M is not positive-definite, set the (restricted) log-likelihood to -Inf
       ### this idea is based on: https://stats.stackexchange.com/q/11368/1934 (this is crude, but should
       ### move the parameter estimates away from values that create the non-positive-definite M matrix)
 
       if (dofit) {
-         stop(mstyle$stop("Final variance-covariance matrix not positive definite."))
+         stop(mstyle$stop("Final variance-covariance matrix not positive definite."), call.=FALSE)
       } else {
          llval <- -Inf
       }
@@ -941,7 +1024,7 @@
       if (inherits(U, "try-error")) {
 
          if (dofit) {
-            stop(mstyle$stop("Cannot fit model based on estimated marginal variance-covariance matrix."))
+            stop(mstyle$stop("Cannot fit model based on estimated marginal variance-covariance matrix."), call.=FALSE)
          } else {
             llval <- -Inf
          }
@@ -950,20 +1033,22 @@
 
          if (!dofit || is.null(A)) {
 
-            sX   <- U %*% X.fit
+            sX   <- U %*% X
             sY   <- U %*% Y
             beta <- solve(crossprod(sX), crossprod(sX, sY))
+            beta <- ifelse(is.na(beta.arg), beta, beta.arg)
             RSS  <- sum(as.vector(sY - sX %*% beta)^2)
             if (dofit)
                vb <- matrix(solve(crossprod(sX)), nrow=pX, ncol=pX)
 
          } else {
 
-            stXAX <- chol2inv(chol(as.matrix(t(X.fit) %*% A %*% X.fit)))
+            stXAX <- chol2inv(chol(as.matrix(t(X) %*% A %*% X)))
             #stXAX <- tcrossprod(qr.solve(sX, diag(k)))
-            beta  <- matrix(stXAX %*% crossprod(X.fit,A) %*% Y, ncol=1)
-            RSS   <- as.vector(t(Y - X.fit %*% beta) %*% W %*% (Y - X.fit %*% beta))
-            vb    <- matrix(stXAX %*% t(X.fit) %*% A %*% M %*% A %*% X.fit %*% stXAX, nrow=pX, ncol=pX)
+            beta  <- matrix(stXAX %*% crossprod(X,A) %*% Y, ncol=1)
+            beta  <- ifelse(is.na(beta.arg), beta, beta.arg)
+            RSS   <- as.vector(t(Y - X %*% beta) %*% W %*% (Y - X %*% beta))
+            vb    <- matrix(stXAX %*% t(X) %*% A %*% M %*% A %*% X %*% stXAX, nrow=pX, ncol=pX)
 
          }
 
@@ -973,8 +1058,8 @@
             llvals[1]  <- -1/2 * (k) * log(2*base::pi) - 1/2 * determinant(M, logarithm=TRUE)$modulus - 1/2 * RSS
 
          if (dofit || reml)
-            llvals[2]  <- -1/2 * (k-pX) * log(2*base::pi) + ifelse(REMLf, 1/2 * determinant(crossprod(X.fit), logarithm=TRUE)$modulus, 0) +
-                          -1/2 * determinant(M, logarithm=TRUE)$modulus - 1/2 * determinant(crossprod(X.fit,W) %*% X.fit, logarithm=TRUE)$modulus - 1/2 * RSS
+            llvals[2]  <- -1/2 * (k-pX) * log(2*base::pi) + ifelse(REMLf, 1/2 * determinant(crossprod(X), logarithm=TRUE)$modulus, 0) +
+                          -1/2 * determinant(M, logarithm=TRUE)$modulus - 1/2 * determinant(crossprod(X,W) %*% X, logarithm=TRUE)$modulus - 1/2 * RSS
 
          if (dofit) {
 
@@ -1014,22 +1099,23 @@
          iteration <- .getfromenv("iteration", default=NULL)
 
          if (!is.null(iteration)) {
-            cat(mstyle$verbose(paste0("Iteration ", iteration, "\t")))
+            #cat(mstyle$verbose(paste0("Iteration ", iteration, "\t")))
+            cat(mstyle$verbose(paste0("Iteration ", formatC(iteration, width=5, flag="-", format="f", digits=0), " ")))
             try(assign("iteration", iteration+1, envir=.metafor), silent=TRUE)
          }
 
       }
 
-      cat(mstyle$verbose(paste0("ll = ", ifelse(is.na(llval), NA, formatC(llval, digits=digits[["fit"]], format="f", flag=" ")))), "  ")
+      cat(mstyle$verbose(paste0("ll = ",             fmtx(llval,  digits[["fit"]], flag=" "))), "  ")
       if (withS)
-         cat(mstyle$verbose(paste0("sigma2 =", paste(ifelse(is.na(sigma2), NA, formatC(sigma2, digits=digits[["var"]], format="f", flag=" ")), collapse=" "), "  ")))
+         cat(mstyle$verbose(paste0("sigma2 =", paste(fmtx(sigma2, digits[["var"]], flag=" "), collapse=" "), "  ")))
       if (withG) {
-         cat(mstyle$verbose(paste0("tau2 =",   paste(ifelse(is.na(tau2),   NA, formatC(tau2,   digits=digits[["var"]], format="f", flag=" ")), collapse=" "), "  ")))
-         cat(mstyle$verbose(paste0("rho =",    paste(ifelse(is.na(rho),    NA, formatC(rho,    digits=digits[["var"]], format="f", flag=" ")), collapse=" "), "  ")))
+         cat(mstyle$verbose(paste0("tau2 =",   paste(fmtx(tau2,   digits[["var"]], flag=" "), collapse=" "), "  ")))
+         cat(mstyle$verbose(paste0("rho =",    paste(fmtx(rho,    digits[["var"]], flag=" "), collapse=" "), "  ")))
       }
       if (withH) {
-         cat(mstyle$verbose(paste0("gamma2 =", paste(ifelse(is.na(gamma2), NA, formatC(gamma2, digits=digits[["var"]], format="f", flag=" ")), collapse=" "), "  ")))
-         cat(mstyle$verbose(paste0("phi =",    paste(ifelse(is.na(phi),    NA, formatC(phi,    digits=digits[["var"]], format="f", flag=" ")), collapse=" "), "  ")))
+         cat(mstyle$verbose(paste0("gamma2 =", paste(fmtx(gamma2, digits[["var"]], flag=" "), collapse=" "), "  ")))
+         cat(mstyle$verbose(paste0("phi =",    paste(fmtx(phi,    digits[["var"]], flag=" "), collapse=" "), "  ")))
       }
       cat("\n")
 
@@ -1067,25 +1153,32 @@
 
       ### fit model without data from ith cluster
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA), gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA), sparse=obj$sparse, dist=obj$dist, control=control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA),
+                   gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA),
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    } else {
 
       ### set values of variance/correlation components to those from the 'full' model
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi, sparse=obj$sparse, dist=obj$dist, control=obj$control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi,
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=obj$control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    }
 
    if (inherits(res, "try-error"))
-      return(list(cook.d = NA))
+      return(list(cook.d = NA_real_))
 
    ### removing a cluster could lead to a model coefficient becoming inestimable
 
    if (any(res$coef.na))
-      return(list(cook.d = NA))
+      return(list(cook.d = NA_real_))
 
    ### compute dfbeta value(s) (including coefficients as specified via btt)
 
@@ -1123,25 +1216,32 @@
 
       ### fit model without data from ith cluster
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA), gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA), sparse=obj$sparse, dist=obj$dist, control=control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA),
+                   gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA),
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    } else {
 
       ### set values of variance/correlation components to those from the 'full' model
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi, sparse=obj$sparse, dist=obj$dist, control=obj$control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi,
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=obj$control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    }
 
    if (inherits(res, "try-error"))
-      return(list(delresid = rep(NA, k.id), sedelresid = rep(NA, k.id), X2 = NA, k.id = NA, pos = which(incl)))
+      return(list(delresid = rep(NA_real_, k.id), sedelresid = rep(NA_real_, k.id), X2 = NA_real_, k.id = NA_integer_, pos = which(incl)))
 
    ### removing a cluster could lead to a model coefficient becoming inestimable
 
    if (any(res$coef.na))
-      return(list(delresid = rep(NA, k.id), sedelresid = rep(NA, k.id), X2 = NA, k.id = NA, pos = which(incl)))
+      return(list(delresid = rep(NA_real_, k.id), sedelresid = rep(NA_real_, k.id), X2 = NA_real_, k.id = NA_integer_, pos = which(incl)))
 
    ### elements that need to be returned
 
@@ -1149,7 +1249,10 @@
 
    ### fit model based on all data but with var/cor components fixed to those from res
 
-   args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=res$sigma2, tau2=res$tau2, rho=res$rho, gamma2=res$gamma2, phi=res$phi, sparse=obj$sparse, dist=obj$dist, control=obj$control, outlist=outlist)
+   args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                sigma2=res$sigma2, tau2=res$tau2, rho=res$rho, gamma2=res$gamma2, phi=res$phi,
+                sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=obj$control, outlist=outlist)
    tmp <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    Xi <- obj$X[incl,,drop=FALSE]
@@ -1162,7 +1265,7 @@
    #sve <- try(solve(tmp$M[incl,incl,drop=FALSE] + vdelpred), silent=TRUE)
 
    if (inherits(sve, "try-error"))
-      return(list(delresid = delresid, sedelresid = sedelresid, X2 = NA, k.id = k.id, pos = which(incl)))
+      return(list(delresid = delresid, sedelresid = sedelresid, X2 = NA_real_, k.id = k.id, pos = which(incl)))
 
    X2 <- c(rbind(delresid) %*% sve %*% cbind(delresid))
 
@@ -1197,25 +1300,32 @@
 
       ### fit model without data from ith cluster
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA), gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA), sparse=obj$sparse, dist=obj$dist, control=control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=ifelse(obj$vc.fix$sigma2, obj$sigma2, NA), tau2=ifelse(obj$vc.fix$tau2, obj$tau2, NA), rho=ifelse(obj$vc.fix$rho, obj$rho, NA),
+                   gamma2=ifelse(obj$vc.fix$gamma2, obj$gamma2, NA), phi=ifelse(obj$vc.fix$phi, obj$phi, NA),
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    } else {
 
       ### set values of variance/correlation components to those from the 'full' model
 
-      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi, sparse=obj$sparse, dist=obj$dist, control=obj$control, subset=!incl, outlist=outlist)
+      args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                   test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                   sigma2=obj$sigma2, tau2=obj$tau2, rho=obj$rho, gamma2=obj$gamma2, phi=obj$phi,
+                   sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=obj$control, subset=!incl, outlist=outlist)
       res <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    }
 
    if (inherits(res, "try-error"))
-      return(list(dfbs = NA))
+      return(list(dfbs = NA_real_))
 
    ### removing a cluster could lead to a model coefficient becoming inestimable
 
    if (any(res$coef.na))
-      return(list(dfbs = NA))
+      return(list(dfbs = NA_real_))
 
    ### elements that need to be returned
 
@@ -1223,7 +1333,10 @@
 
    ### fit model based on all data but with var/cor components fixed to those from res
 
-   args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method, test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale, sigma2=res$sigma2, tau2=res$tau2, rho=res$rho, gamma2=res$gamma2, phi=res$phi, sparse=obj$sparse, dist=obj$dist, control=obj$control, outlist=outlist)
+   args <- list(yi=obj$yi, V=obj$V, W=obj$W, mods=obj$X, random=obj$random, struct=obj$struct, intercept=FALSE, data=obj$mf.r, method=obj$method,
+                test=obj$test, dfs=obj$dfs, level=obj$level, R=obj$R, Rscale=obj$Rscale,
+                sigma2=res$sigma2, tau2=res$tau2, rho=res$rho, gamma2=res$gamma2, phi=res$phi,
+                sparse=obj$sparse, dist=obj$dist, vccon=obj$vccon, control=obj$control, outlist=outlist)
    tmp <- try(suppressWarnings(.do.call(rma.mv, args)), silent=TRUE)
 
    ### compute dfbeta value(s)
@@ -1242,7 +1355,7 @@
 
 .ddf.calc <- function(dfs, X, k, p, mf.s=NULL, mf.g=NULL, mf.h=NULL, beta=TRUE) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (beta) {
 
@@ -1251,7 +1364,7 @@
          if (length(ddf) == 1L)
             ddf <- rep(ddf, p)
          if (length(ddf) != p)
-            stop(mstyle$stop(paste0("Length of 'dfs' argument (", length(dfs), ") does not match the number of model coefficient (", p, ").")))
+            stop(mstyle$stop(paste0("Length of 'dfs' argument (", length(dfs), ") does not match the number of model coefficient (", p, ").")), call.=FALSE)
       }
 
       if (is.character(dfs) && dfs == "residual")
