@@ -4,18 +4,18 @@
 
 .set.btt <- function(btt, p, int.incl, Xnames, fixed=FALSE) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (missing(btt) || is.null(btt)) {
 
-      if (p > 1L) {                       ### if the model matrix has more than one column
+      if (p > 1L) {                       # if the model matrix has more than one column
          if (int.incl) {
-            btt <- seq.int(from=2, to=p)     ### and the model has an intercept term, test all coefficients except the intercept
+            btt <- seq.int(from=2, to=p)     # and the model has an intercept term, test all coefficients except the intercept
          } else {
-            btt <- seq_len(p)                ### and the model does not have an intercept term, test all coefficients
+            btt <- seq_len(p)                # and the model does not have an intercept term, test all coefficients
          }
       } else {
-         btt <- 1L                        ### if the model matrix has a single column, test that single coefficient
+         btt <- 1L                        # if the model matrix has a single column, test that single coefficient
       }
 
    } else {
@@ -96,38 +96,83 @@
 
 ### pairwise sorting of the elements of two vectors
 
-.psort <- function(x,y) {
+#.psort.old <- function(x, y) {
+#
+#   if (is.null(x) || length(x) == 0L) # need to catch this
+#      return(NULL)
+#
+#   if (missing(y)) {
+#      if (is.matrix(x)) {
+#         xy <- x
+#      } else {
+#         xy <- rbind(x) # in case x is just a vector
+#      }
+#   } else {
+#      xy <- cbind(x,y)
+#   }
+#
+#   n <- nrow(xy)
+#
+#   for (i in seq_len(n)) {
+#      if (anyNA(xy[i,]))
+#         next
+#      xy[i,] <- sort(xy[i,])
+#   }
+#
+#   colnames(xy) <- NULL
+#
+#   return(xy)
+#
+#}
 
-   ### t(apply(xy, 1, sort)) would be okay, but problematic if there are NAs;
-   ### either they are removed completely (na.last=NA) or they are always put
-   ### first/last (na.last=FALSE/TRUE); but we just want to leave the NAs in
-   ### their position!
+.psort <- function(x, y, as.list=FALSE) {
 
-   if (is.null(x) || length(x) == 0L) ### need to catch this
+   # simpler / vectorized version that also deals with x and y being matrices
+   # (of the same dimensions) for elementwise swapping of pairs as needed
+
+   # t(apply(xy, 1, sort)) would be okay, but problematic if there are NAs;
+   # either they are removed completely (na.last=NA) or they are always put
+   # first/last (na.last=FALSE/TRUE); but we just want to leave the NAs in
+   # their position!
+
+   if (is.null(x) || length(x) == 0L) # need to catch this
       return(NULL)
 
    if (missing(y)) {
       if (is.matrix(x)) {
-         xy <- x
+         y <- x[,2]
+         x <- x[,1]
       } else {
-         xy <- rbind(x) ### in case x is just a vector
+         y <- x[2]
+         x <- x[1]
       }
+   }
+
+   flip <- x > y
+   flip[is.na(flip)] <- FALSE
+
+   x.flip <- x
+   y.flip <- y
+
+   x.flip[flip] <- y[flip]
+   y.flip[flip] <- x[flip]
+
+   if (as.list) {
+      return(list(x=x.flip, y=y.flip))
    } else {
-      xy <- cbind(x,y)
+      return(cbind(x.flip, y.flip))
    }
 
-   n <- nrow(xy)
+}
 
-   for (i in seq_len(n)) {
-      if (anyNA(xy[i,]))
-         next
-      xy[i,] <- sort(xy[i,])
-   }
+############################################################################
 
-   colnames(xy) <- NULL
-
-   return(xy)
+### function for applying observation limits
 
+.applyolim <- function(x, olim) {
+   x[x < olim[1]] <- olim[1]
+   x[x > olim[2]] <- olim[2]
+   return(x)
 }
 
 ############################################################################
@@ -192,6 +237,35 @@
    is.numeric(x)
 }
 
+### sapply()-like function but for matrices that always preserves the matrix dimensions (used in traceplot.rma.uni())
+
+.matapply <- function(x, FUN, targs=NULL) {
+   if (is.null(x))
+      return(NULL)
+   if (is.null(targs)) {
+      x[] <- sapply(x, FUN)
+   } else {
+      x[] <- sapply(x, FUN, targs)
+   }
+   return(x)
+}
+
+### check if ddd element is NULL; if so, return ifnull, otherwise the ddd element or ifnot
+
+.chkddd <- function(x, ifnull=NULL, ifnot=NULL) {
+
+   if (is.null(x)) {
+      return(ifnull)
+   } else {
+      if (is.null(ifnot)) {
+         return(x)
+      } else {
+         return(ifnot)
+      }
+   }
+
+}
+
 ############################################################################
 
 ### function to format p-values (no longer used; use fmtp() instead)
@@ -225,17 +299,21 @@
 
 ### function to handle 'level' argument
 
-.level <- function(level, allow.vector=FALSE) {
+.level <- function(level, allow.vector=FALSE, argname="level", stopon100=FALSE) {
 
-   if (!allow.vector && length(level) != 1L) {
-      mstyle <- .get.mstyle("crayon" %in% .packages())
-      stop(mstyle$stop("Argument 'level' must specify a single value."), call.=FALSE)
-   }
+   mstyle <- .get.mstyle()
 
-   if (!is.numeric(level)) {
-      mstyle <- .get.mstyle("crayon" %in% .packages())
-      stop(mstyle$stop("The 'level' argument must be numeric."), call.=FALSE)
-   }
+   if (any(level > 100) || any(level < 0))
+      stop(mstyle$stop(paste0("Argument '", argname, "' must be between 0 and 100.")), call.=FALSE)
+
+   if (isTRUE(stopon100) && any(level==100))
+      stop(mstyle$stop(paste0("Argument '", argname, "' cannot be equal to 100.")), call.=FALSE)
+
+   if (!allow.vector && length(level) != 1L)
+      stop(mstyle$stop(paste0("Argument '", argname, "' must specify a single value.")), call.=FALSE)
+
+   if (!is.numeric(level))
+      stop(mstyle$stop(paste0("The '", argname, "' argument must be numeric.")), call.=FALSE)
 
    ifelse(level == 0, 1, ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)))
 
@@ -304,26 +382,29 @@
 ############################################################################
 
 .space <- function(x=TRUE) {
-   no.rmspace <- !exists(".rmspace")
-   if (no.rmspace && x)
+   if (exists(".rmspace")) {
+      addspace <- FALSE
+   } else {
+      addspace <- isTRUE(getmfopt("space", default=TRUE))
+   }
+   if (addspace && x)
       cat("\n")
-   if (!no.rmspace && !x)
+   if (!addspace && !x)
       cat("\n")
 }
 
 .get.footsym <- function() {
 
-   if (exists(".footsym")) {
-      fs <- get(".footsym")
-   } else {
+   fs <- getmfopt("footsym")
+
+   if (is.null(fs) || length(fs) != 6L)
       fs <- c("\u00b9", "1)", "\u00b2", "2)", "\u00b3", "3)")
-   }
 
    return(fs)
 
 }
 
-# .footsym <- c("\u00b9", "\u00b9\u207e", "\u00b2", "\u00b2\u207e", "\u00b3", "\u00b3\u207e")
+# setmfopt(footsym = c("\u00b9", "\u00b9\u207e", "\u00b2", "\u00b2\u207e", "\u00b3", "\u00b3\u207e"))
 
 ############################################################################
 
@@ -331,7 +412,7 @@
 
 .print.time <- function(x) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    hours   <- floor(x/60/60)
    minutes <- floor(x/60) - hours*60
@@ -378,7 +459,7 @@
       ddd[okargs[i]] <- NULL
 
    if (length(ddd) > 0L) {
-      mstyle <- .get.mstyle("crayon" %in% .packages())
+      mstyle <- .get.mstyle()
       warning(mstyle$warning(paste0("Extra argument", ifelse(length(ddd) > 1L, "s ", " "), "(", paste0("'", names(ddd), "'", collapse=", "), ") disregarded.")), call.=FALSE)
    }
 
@@ -388,7 +469,7 @@
 
 .getx <- function(x, mf, data, enclos=sys.frame(sys.parent(n=2)), checknull=TRUE, checknumeric=FALSE, default) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    mf.getx <- match.call()
    dname <- deparse1(mf.getx[[match("data", names(mf.getx))]])
@@ -474,7 +555,7 @@
 
 .chkclass <- function(class, must, notap, notav, type="Method") {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    obj <- as.character(match.call()[2])
    obj <- substr(obj, 7, nchar(obj)-1)
@@ -530,8 +611,8 @@
          ok <- TRUE
 
       if (!ok) {
-         mstyle <- .get.mstyle("crayon" %in% .packages())
-         warning(mstyle$warning(paste0("The 'vi' argument is for specifying the sampling variances,\nbut '", x, "' sounds like this variable may contain standard\nerrors (maybe use 'sei=", x, "' instead?).")), call.=FALSE)
+         mstyle <- .get.mstyle()
+         warning(mstyle$warning(paste0("The 'vi' argument should be used to specify sampling variances,\nbut '", x, "' sounds like this variable may contain standard\nerrors (maybe use 'sei=", x, "' instead?).")), call.=FALSE)
          try(assign("runvicheck", FALSE, envir=.metafor), silent=TRUE)
       }
 
@@ -550,7 +631,7 @@
    if (all(ks == 0L)) { # if all elements have length 0 (are NULL), return TRUE
       return(TRUE)
    } else {
-      ks <- ks[ks > 0L]  # keep the non-zero lengths
+      ks <- ks[ks > 0L] # keep the non-zero lengths
       return(length(unique(ks)) == 1L) # check that they are all identical
    }
 
@@ -813,6 +894,26 @@
          }
       }
       ######################################################################
+      if (measure == "R2") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Coefficient of Determination")
+         }
+      }
+      if (measure == "ZR2") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression(z[R^2]), "z Transformed Coefficient of Determination")
+         } else {
+            lab <- ifelse(short, lab, "Transformed z Transformed Coefficient of Determination")
+            funlist <- lapply(list(transf.ztor2), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+         }
+      }
+      ######################################################################
       if (measure == "PR") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, "Proportion", "Proportion")
@@ -920,6 +1021,13 @@
             lab <- ifelse(short, lab, "Transformed Mean")
          }
       }
+      if (measure == "SMN") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, "Std. Mean", "Standardized Mean")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Standardized Mean")
+         }
+      }
       if (measure == "MNLN") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, "Log[Mean]", "Log Mean")
@@ -932,13 +1040,6 @@
                lab <- ifelse(short, "Mean", "Mean")
          }
       }
-      if (measure == "SMN") {
-         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
-            lab <- ifelse(short, "SM", "Standardized Mean")
-         } else {
-            lab <- ifelse(short, lab, "Transformed Standardized Mean")
-         }
-      }
       if (measure == "CVLN") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, "Log[CV]", "Log Coefficient of Variation")
@@ -971,7 +1072,7 @@
             lab <- ifelse(short, lab, "Transformed Mean Change")
          }
       }
-      if (is.element(measure, c("SMCC","SMCR","SMCRH"))) {
+      if (is.element(measure, c("SMCC","SMCR","SMCRH","SMCRP","SMCRPH"))) {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, "SMC", "Standardized Mean Change")
          } else {
@@ -1060,6 +1161,26 @@
          }
       }
       ######################################################################
+      if (measure == "HR") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, "Log[HR]", "Log Hazard Ratio")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Log Hazard Ratio")
+            funlist <- lapply(list(exp, transf.exp.int), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, "HR", "Hazard Ratio (log scale)")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, "HR", "Hazard Ratio")
+         }
+      }
+      if (measure == "HD") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, "HD", "Hazard Difference")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Hazard Difference")
+         }
+      }
+      ######################################################################
 
    }
 
@@ -1071,18 +1192,35 @@
 
 ### stuff related to colored/styled output
 
-.get.mstyle <- function(withcrayon) {
+.get.mstyle <- function() {
 
-   if (withcrayon) {
+   crayonloaded <- "crayon" %in% .packages()
+
+   styleopt <- getmfopt("style")
+
+   if (is.logical(styleopt)) {
+
+      if (isTRUE(styleopt)) {
+         styleopt <- NULL
+      } else {
+         crayonloaded <- FALSE
+      }
+   }
+
+   if (crayonloaded) {
 
       if (exists(".mstyle")) {
          .mstyle <- get(".mstyle")
-         if (!is.list(.mstyle))
-            .mstyle <- list(.mstyle)
       } else {
          .mstyle <- list()
       }
 
+      if (!is.null(styleopt))
+         .mstyle <- styleopt
+
+      if (!is.list(.mstyle))
+         .mstyle <- list(.mstyle)
+
       if (is.null(.mstyle$section)) {
          section <- crayon::bold
       } else {
@@ -1148,6 +1286,7 @@
    } else {
 
       tmp <- function(...) paste0(...)
+
       section <- tmp
       header  <- tmp
       body1   <- tmp
@@ -1259,6 +1398,14 @@
       res[c(na.omit(pos))] <- .digits[!is.na(pos)]
    }
 
+   if (!is.null(getmfopt("digits"))) {
+      .digits <- getmfopt("digits")
+      if (length(.digits) == 1L)
+         .digits <- c(est=.digits[[1]], se=.digits[[1]], test=.digits[[1]], pval=.digits[[1]], ci=.digits[[1]], var=.digits[[1]], sevar=.digits[[1]], fit=.digits[[1]], het=.digits[[1]])
+      pos <- pmatch(names(.digits), names(res))
+      res[c(na.omit(pos))] <- .digits[!is.na(pos)]
+   }
+
    if (!dmiss) {
       if (is.null(names(digits))) {
          res <- c(est=digits[[1]], se=digits[[1]], test=digits[[1]], pval=digits[[1]], ci=digits[[1]], var=digits[[1]], sevar=digits[[1]], fit=digits[[1]], het=digits[[1]])
@@ -1350,7 +1497,7 @@
    if (is.null(x)) # if x is NULL, return x (i.e., NULL)
       return(x)
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    argname <- deparse(substitute(x))
 
@@ -1398,7 +1545,7 @@
    if (is.null(x) || is.null(subset)) # if x or subset is NULL, return x
       return(x)
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    xname <- deparse(substitute(x))
 
@@ -1438,93 +1585,21 @@
 
 ############################################################################
 
-.tes.intfun <- function(x, theta, tau, sei, H0, alternative, crit) {
-   if (alternative == "two.sided")
-      pow <- (pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=FALSE) + pnorm(-crit, mean=(x-H0)/sei, sd=1, lower.tail=TRUE))
-   if (alternative == "greater")
-      pow <- pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=FALSE)
-   if (alternative == "less")
-      pow <- pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=TRUE)
-   res <- pow * dnorm(x, theta, tau)
-   return(res)
-}
+.chkopt <- function(optimizer, optcontrol, ineq=FALSE) {
 
-.tes.lim <- function(theta, yi, vi, H0, alternative, alpha, tau2, test, tes.alternative, progbar, tes.alpha, correct, rel.tol, subdivisions, tau2.lb) {
-   pval <- tes(x=yi, vi=vi, H0=H0, alternative=alternative, alpha=alpha, theta=theta, tau2=tau2, test=test, tes.alternative=tes.alternative, progbar=progbar,
-                       tes.alpha=tes.alpha, correct=correct, rel.tol=rel.tol, subdivisions=subdivisions, tau2.lb=tau2.lb, find.lim=FALSE)$pval
-   #cat("theta = ", theta, " pval = ", pval, "\n")
-   return(pval - tes.alpha)
-}
+   mstyle <- .get.mstyle()
 
-############################################################################
-
-.fsn.fisher <- function(fsnum, pi, alpha) {
-   k <- length(pi)
-   X2 <- -2*sum(log(c(pi, rep(0.5, fsnum))))
-   return(pchisq(X2, df=2*(k+fsnum), lower.tail=FALSE) - alpha)
-}
-
-.fsn.fitre <- function(yi, vi) {
-
-   k     <- length(yi)
-   wi    <- 1/vi
-   sumwi <- sum(wi)
-   est   <- sum(wi*yi)/sumwi
-   Q     <- sum(wi * (yi - est)^2)
-   tau2  <- max(0, (Q - (k-1)) / (sumwi - sum(wi^2)/sumwi))
-   wi    <- 1 / (vi + tau2)
-   sumwi <- sum(wi)
-   est   <- sum(wi*yi)/sumwi
-   se    <- sqrt(1 / sumwi)
-   zval  <- est / se
-   pval  <- 2*pnorm(abs(zval), lower.tail=FALSE)
-
-   return(list(est=est, se=se, zval=zval, pval=pval, tau2=tau2))
-
-}
-
-.fsn.fitnew <- function(new, yi, vi, vnew, tau2, alpha, iters) {
-
-   new <- ceiling(new)
-
-   mus   <- rep(NA_real_, iters)
-   pvals <- rep(NA_real_, iters)
-
-   for (j in seq_len(iters)) {
-      yinew <- c(yi, rnorm(new, 0, sqrt(vnew+tau2)))
-      vinew <- c(vi, rep(vnew, new))
-      tmp <- .fsn.fitre(yinew, vinew)
-      mus[j] <- tmp$est
-      pvals[j] <- tmp$pval
-   }
-
-   return(list(mean = mean(mus), rejrate = mean(pvals <= alpha)))
-
-}
-
-.fsn.re <- function(fsnum, yi, vi, vnew, tau2, target, alpha, iters, verbose=FALSE) {
-
-   fsnum <- ceiling(fsnum)
-   tmp <- .fsn.fitnew(fsnum, yi, vi, vnew, tau2, alpha, iters)
-   est <- tmp$mean
-   diff <- est - target
-   if (verbose)
-      cat("fsnum =", formatC(fsnum, width=4, format="d"), "  est =", fmtx(est), "  target =", fmtx(target), "  diff =", fmtx(diff, flag=" "), "\n")
-   return(diff)
-
-}
-
-############################################################################
-
-.chkopt <- function(optimizer, optcontrol) {
-
-   mstyle <- .get.mstyle("crayon" %in% .packages())
-
-   ### set NLOPT_LN_BOBYQA as the default algorithm for nloptr optimizer
+   ### set NLOPT_LN_BOBYQA as the default algorithm for the nloptr optimizer when ineq=FALSE
+   ### and otherwise use NLOPT_LN_COBYLA to allow for nonlinear inequality constraints
    ### and by default use a relative convergence criterion of 1e-8 on the function value
 
-   if (optimizer == "nloptr" && !is.element("algorithm", names(optcontrol)))
-      optcontrol$algorithm <- "NLOPT_LN_BOBYQA"
+   if (optimizer == "nloptr" && !is.element("algorithm", names(optcontrol))) {
+      if (ineq) {
+         optcontrol$algorithm <- "NLOPT_LN_COBYLA"
+      } else {
+         optcontrol$algorithm <- "NLOPT_LN_BOBYQA"
+      }
+   }
 
    if (optimizer == "nloptr" && !is.element("ftol_rel", names(optcontrol)))
       optcontrol$ftol_rel <- 1e-8
@@ -1585,13 +1660,13 @@
    }
 
    if (optimizer == "Rcgmin") {
-      if (!requireNamespace("Rcgmin", quietly=TRUE))
-         stop(mstyle$stop("Please install the 'Rcgmin' package to use this optimizer."), call.=FALSE)
+      if (!requireNamespace(optimizer, quietly=TRUE))
+         stop(mstyle$stop(paste0("Please install the '", optimizer, "' package to use this optimizer.")), call.=FALSE)
    }
 
    if (optimizer == "Rvmmin") {
-      if (!requireNamespace("Rvmmin", quietly=TRUE))
-         stop(mstyle$stop("Please install the 'Rvmmin' package to use this optimizer."), call.=FALSE)
+      if (!requireNamespace(optimizer, quietly=TRUE))
+         stop(mstyle$stop(paste0("Please install the '", optimizer, "' package to use this optimizer.")), call.=FALSE)
    }
 
    #########################################################################
@@ -1690,7 +1765,7 @@
 
 .chkconv <- function(optimizer, opt.res, optcontrol, fun, verbose) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    if (optimizer == "optimParallel::optimParallel" && verbose) {
       tmp <- capture.output(print(opt.res$loginfo))
@@ -1700,7 +1775,7 @@
    ### convergence checks
 
    if (inherits(opt.res, "try-error"))
-      stop(mstyle$stop(paste0("Error during the optimization. Use verbose=TRUE and see help(", fun, ") for more details on the optimization routines.")), call.=FALSE)
+      stop(mstyle$stop(paste0("Error during the optimization. Use verbose=TRUE and see\n       help(", fun, ") for more details on the optimization routines.")), call.=FALSE)
 
    if (optimizer == "lbfgsb3c::lbfgsb3c" && is.null(opt.res$convergence)) # special provision for lbfgsb3c in case 'convergence' is missing
       opt.res$convergence <- -99
@@ -1784,3 +1859,147 @@
 }
 
 ############################################################################
+
+# theme="default" - uses the default par() of the plotting device
+# theme="light"   - forces par(fg="black",  bg="white", ...)
+# theme="dark"    - forces par(fg="gray95", bg="gray10", ...)
+# theme="auto"    - in RStudio, picks fg/bg based on theme that is set (outside RStudio, same as "default")
+# theme="custom"  - uses getmfopt("fg") and getmfopt("bg")
+
+.start.plot <- function(x=TRUE) {
+
+   if (!x)
+      return()
+
+   themeopt <- getmfopt("theme", default="default")[[1]]
+   themeopt <- sub("2", "", themeopt, fixed=TRUE)
+
+   if (!is.element(themeopt, c("default", "light", "dark", "auto", "custom")))
+      themeopt <- "default"
+
+   if (exists(".darkplots"))
+      themeopt <- "dark"
+
+   if (isTRUE(themeopt == "light")) {
+      fg <- "black"
+      bg <- "white"
+      #fg <- "gray5"
+      #bg <- "gray95"
+   }
+
+   if (isTRUE(themeopt == "dark")) {
+      fg <- "gray95"
+      bg <- "gray10"
+   }
+
+   if (isTRUE(themeopt == "auto")) {
+
+      rsapi <- try(rstudioapi::isAvailable(), silent=TRUE)
+
+      if (inherits(rsapi, "try-error") || isFALSE(rsapi)) {
+         themeopt <- "default"
+      } else {
+         fg <- .rsapicol2rgb(rstudioapi::getThemeInfo()$foreground)
+         bg <- .rsapicol2rgb(rstudioapi::getThemeInfo()$background)
+      }
+
+   }
+
+   if (isTRUE(themeopt == "custom")) {
+
+      fgopt <- getmfopt("fg")
+      bgopt <- getmfopt("bg")
+
+      if (is.null(fgopt) || is.null(bgopt)) {
+         themeopt <- "default"
+      } else {
+         fg <- fgopt
+         bg <- bgopt
+      }
+
+   }
+
+   if (themeopt != "default")
+      par(fg=fg, bg=bg, col=fg, col.axis=fg, col.lab=fg, col.main=fg, col.sub=fg)
+
+   invisible()
+
+}
+
+# convert the string "rgb(val1, val2, val3)" into rgb(val1, val2, val3, maxColorValue=255)
+
+.rsapicol2rgb <- function(col) {
+
+   col  <- strsplit(col, ",")[[1]]
+   col  <- trimws(col)
+   col1 <- as.numeric(sub("rgb(", "", col[1], fixed=TRUE))
+   col2 <- as.numeric(col[2])
+   col3 <- as.numeric(trimws(sub(")", "", col[3], fixed=TRUE)))
+   col  <- rgb(col1, col2, col3, maxColorValue=255)
+   return(col)
+
+}
+
+.is.dark <- function() {
+
+   rgb <- col2rgb(par("bg"))
+   res <- sum(rgb) <= 384 # note: sum(col2rgb(rgb(0.5,0.5,0.5))) == 384
+   return(res)
+
+}
+
+.coladj <- function(col, dark, light) {
+
+   themeopt <- getmfopt("theme", default="default")
+
+   if (length(col) == 2L && substr(themeopt, nchar(themeopt), nchar(themeopt)) == "2") {
+      pos <- 2
+      if (length(dark) == 1L)
+         dark <- c(dark, ifelse(dark > 0, dark-1, dark+1))
+      if (length(light) == 1L)
+         light <- c(light, ifelse(light > 0, light-1, light+1))
+   } else {
+      pos <- 1
+   }
+
+   col <- c(col2rgb(col[[pos]]))
+
+   if (.is.dark()) {
+      col <- col + round(dark*255)[[pos]]
+   } else {
+      col <- col + round(light*255)[[pos]]
+   }
+
+   col[col < 0] <- 0
+   col[col > 255] <- 255
+
+   col <- rgb(col[1], col[2], col[3], maxColorValue=255)
+   return(col)
+
+}
+
+############################################################################
+
+.chkpd <- function(x, tol=.Machine$double.eps, corr=FALSE, nearpd=FALSE) {
+
+   if (any(eigen(x, symmetric=TRUE, only.values=TRUE)$values <= tol)) {
+      ispd <- FALSE
+      if (nearpd) {
+         tmp <- nearPD(x, corr=corr)
+         x <- as.matrix(tmp$mat)
+         if (tmp$converged)
+            ispd <- TRUE
+      }
+   } else {
+      ispd <- TRUE
+   }
+
+   if (nearpd) {
+      return(list(ispd=ispd, x=x))
+   } else {
+      return(ispd)
+   }
+
+}
+
+############################################################################
