@@ -3,7 +3,7 @@ digits, cols, grid=TRUE, pch=19, cex=1, lwd=2, ...) {
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(x), must="cumul.rma")
 
@@ -12,13 +12,10 @@ digits, cols, grid=TRUE, pch=19, cex=1, lwd=2, ...) {
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
       stop(mstyle$stop("Unknown 'na.action' specified under options()."))
 
-   if (missing(cols)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         cols <- c("gray30","gray80")
-      } else {
-         cols <- c("gray80","gray20")
-      }
-   }
+   .start.plot()
+
+   if (missing(cols))
+      cols <- c(.coladj(par("bg","fg"), dark=0.2, light=-0.2), .coladj(par("bg","fg"), dark=0.8, light=-0.8))
 
    if (missing(yaxis)) {
       if (is.null(x$tau2)) {
@@ -91,20 +88,16 @@ digits, cols, grid=TRUE, pch=19, cex=1, lwd=2, ...) {
 
    ### grid argument can either be a logical or a color
 
-   if (is.logical(grid)) {
-      if (is.element(par("bg"), c("black", "gray10"))) {
-         gridcol <- "gray30"
-      } else {
-         gridcol <- "gray70"
-      }
-   }
+   if (is.logical(grid))
+      gridcol <- .coladj(par("bg","fg"), dark=c(0.2,-0.6), light=c(-0.2,0.6))
+
    if (is.character(grid)) {
       gridcol <- grid
       grid <- TRUE
    }
 
-   lplot <- function(..., addgrid) plot(...)
-   laxis <- function(..., addgrid) axis(...)
+   lplot <- function(..., addgrid, at.lab) plot(...)
+   laxis <- function(..., addgrid, at.lab) axis(...)
 
    #########################################################################
 
@@ -175,16 +168,24 @@ digits, cols, grid=TRUE, pch=19, cex=1, lwd=2, ...) {
       at <- at[at < par("usr")[2]]
    }
 
-   at.lab <- at
+   if (is.null(ddd$at.lab)) {
 
-   if (is.function(atransf)) {
-      if (is.null(targs)) {
-         at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
+      at.lab <- at
+
+      if (is.function(atransf)) {
+         if (is.null(targs)) {
+            at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
+         } else {
+            at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
+         }
       } else {
-         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
+         at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
       }
+
    } else {
-      at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
+
+      at.lab <- ddd$at.lab
+
    }
 
    ### add x-axis
@@ -238,7 +239,7 @@ digits, cols, grid=TRUE, pch=19, cex=1, lwd=2, ...) {
 
    ### redraw box around plot
 
-   box()
+   box(...)
 
    ### return data frame invisibly
 
