@@ -3,7 +3,7 @@ level, digits, transf, targs, vcov=FALSE, ...) {
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="rma.ls")
 
@@ -44,11 +44,7 @@ level, digits, transf, targs, vcov=FALSE, ...) {
 
    .chkdots(ddd, c("pi.type", "newvi"))
 
-   if (is.null(ddd$pi.type)) {
-      pi.type <- "default"
-   } else {
-      pi.type <- ddd$pi.type
-   }
+   pi.type <- .chkddd(ddd$pi.type, "default", tolower(ddd$pi.type))
 
    if (!is.null(newmods) && x$int.only && !(x$int.only && identical(newmods, 1)))
       stop(mstyle$stop("Cannot specify new moderator values for models without moderators."))
@@ -56,6 +52,8 @@ level, digits, transf, targs, vcov=FALSE, ...) {
    if (!is.null(newscale) && x$Z.int.only && !(x$Z.int.only && identical(newscale, 1)))
       stop(mstyle$stop("Cannot specify new scale values for models without scale variables."))
 
+   rnames <- NULL
+
    #########################################################################
 
    if (!is.null(newmods)) {
@@ -66,16 +64,24 @@ level, digits, transf, targs, vcov=FALSE, ...) {
          stop(mstyle$stop(paste0("Argument 'newmods' should be a vector or matrix, but is of class '", class(newmods), "'.")))
 
       if ((!x$int.incl && x$p == 1L) || (x$int.incl && x$p == 2L)) {
-         k.new <- length(newmods)                               # if single moderator (multiple k.new possible) (either without or with intercept in the model)
-         X.new <- cbind(c(newmods))                             #
-      } else {                                                  # in case the model has more than one predictor:
-         if (.is.vector(newmods) || nrow(newmods) == 1L) {      #   # if user gives one vector or one row matrix (only one k.new):
-            k.new <- 1                                          #
-            X.new <- rbind(newmods)                             #
-         } else {                                               #   # if user gives multiple rows and columns (multiple k.new):
-            k.new <- nrow(newmods)                              #
-            X.new <- cbind(newmods)                             #
-         }                                                      #
+         k.new <- length(newmods)                                # if single moderator (multiple k.new possible) (either without or with intercept in the model)
+         X.new <- cbind(c(newmods))                              #
+         if (.is.vector(newmods)) {                              #
+            rnames <- names(newmods)                             #
+         } else {                                                #
+            rnames <- rownames(newmods)                          #
+         }                                                       #
+      } else {                                                   # in case the model has more than one predictor:
+         if (.is.vector(newmods) || nrow(newmods) == 1L) {       #   # if user gives one vector or one row matrix (only one k.new):
+            k.new <- 1                                           #
+            X.new <- rbind(newmods)                              #
+            if (inherits(newmods, "matrix"))                     #
+               rnames <- rownames(newmods)                       #
+         } else {                                                #   # if user gives multiple rows and columns (multiple k.new):
+            k.new <- nrow(newmods)                               #
+            X.new <- cbind(newmods)                              #
+            rnames <- rownames(newmods)                          #
+         }                                                       #
          ### allow matching of terms by names (note: only possible if all columns in X.new and x$X have colnames)
          if (!is.null(colnames(X.new)) && all(colnames(X.new) != "") && !is.null(colnames(x$X)) && all(colnames(x$X) != "")) {
             colnames.mod <- colnames(x$X)
@@ -84,10 +90,10 @@ level, digits, transf, targs, vcov=FALSE, ...) {
             pos <- sapply(colnames(X.new), function(colname) {
                      d <- c(adist(colname, colnames.mod, costs=c(ins=1, sub=Inf, del=Inf))) # compute edit distances with Inf costs for substitutions/deletions
                      if (all(is.infinite(d))) # if there is no match, then all elements are Inf
-                        stop(mstyle$stop(paste0("Could not find variable '", colname, "' in the model.")), call. = FALSE)
+                        stop(mstyle$stop(paste0("Could not find variable '", colname, "' in the model.")))
                      d <- which(d == min(d)) # don't use which.min() since that only finds the first minimum
                      if (length(d) > 1L) # if there is no unique match, then there is more than one minimum
-                        stop(mstyle$stop(paste0("Could not match up variable '", colname, "' uniquely to a variable in the model.")), call. = FALSE)
+                        stop(mstyle$stop(paste0("Could not match up variable '", colname, "' uniquely to a variable in the model.")))
                      return(d)
                      })
             if (anyDuplicated(pos)) { # if the same name is used more than once, then there will be duplicated pos values
@@ -134,16 +140,27 @@ level, digits, transf, targs, vcov=FALSE, ...) {
          stop(mstyle$stop(paste0("Argument 'newscale' should be a vector or matrix, but is of class '", class(newscale), "'.")))
 
       if ((!x$Z.int.incl && x$q == 1L) || (x$Z.int.incl && x$q == 2L)) {
-         Z.k.new <- length(newscale)                            # if single moderator (multiple k.new possible) (either without or with intercept in the model)
-         Z.new <- cbind(c(newscale))                            #
-      } else {                                                  # in case the model has more than one predictor:
-         if (.is.vector(newscale) || nrow(newscale) == 1L) {    #   # if user gives one vector or one row matrix (only one k.new):
-            Z.k.new <- 1                                        #
-            Z.new <- rbind(newscale)                            #
-         } else {                                               #   # if user gives multiple rows and columns (multiple k.new):
-            Z.k.new <- nrow(newscale)                           #
-            Z.new <- cbind(newscale)                            #
-         }                                                      #
+         Z.k.new <- length(newscale)                             # if single moderator (multiple k.new possible) (either without or with intercept in the model)
+         Z.new <- cbind(c(newscale))                             #
+         if (is.null(rnames)) {                                  #
+            if (.is.vector(newscale)) {                          #
+               rnames <- names(newscale)                         #
+            } else {                                             #
+               rnames <- rownames(newscale)                      #
+            }                                                    #
+         }                                                       #
+      } else {                                                   # in case the model has more than one predictor:
+         if (.is.vector(newscale) || nrow(newscale) == 1L) {     #   # if user gives one vector or one row matrix (only one k.new):
+            Z.k.new <- 1                                         #
+            Z.new <- rbind(newscale)                             #
+            if (is.null(rnames) && inherits(newscale, "matrix")) #
+               rnames <- rownames(newscale)                      #
+         } else {                                                #   # if user gives multiple rows and columns (multiple k.new):
+            Z.k.new <- nrow(newscale)                            #
+            Z.new <- cbind(newscale)                             #
+            if (is.null(rnames))                                 #
+               rnames <- rownames(newscale)                      #
+         }                                                       #
          ### allow matching of terms by names (note: only possible if all columns in Z.new and x$Z have colnames)
          if (!is.null(colnames(Z.new)) && all(colnames(Z.new) != "") && !is.null(colnames(x$Z)) && all(colnames(x$Z) != "")) {
             colnames.mod <- colnames(x$Z)
@@ -152,10 +169,10 @@ level, digits, transf, targs, vcov=FALSE, ...) {
             pos <- sapply(colnames(Z.new), function(colname) {
                      d <- c(adist(colname, colnames.mod, costs=c(ins=1, sub=Inf, del=Inf))) # compute edit distances with Inf costs for substitutions/deletions
                      if (all(is.infinite(d))) # if there is no match, then all elements are Inf
-                        stop(mstyle$stop(paste0("Could not find variable '", colname, "' from 'newscale' in the model.")), call. = FALSE)
+                        stop(mstyle$stop(paste0("Could not find variable '", colname, "' from 'newscale' in the model.")))
                      d <- which(d == min(d)) # don't use which.min() since that only finds the first minimum
                      if (length(d) > 1L) # if there is no unique match, then there is more than one minimum
-                        stop(mstyle$stop(paste0("Could not match up variable '", colname, "' from 'newscale' uniquely to a variable in the model.")), call. = FALSE)
+                        stop(mstyle$stop(paste0("Could not match up variable '", colname, "' from 'newscale' uniquely to a variable in the model.")))
                      return(d)
                      })
             if (anyDuplicated(pos)) { # if the same name is used more than once, then there will be duplicated pos values
@@ -414,12 +431,16 @@ level, digits, transf, targs, vcov=FALSE, ...) {
          slab <- x$slab
       } else {
          slab <- seq_len(k.new)
+         if (!is.null(rnames))
+            slab <- rnames
       }
    } else {
       if (is.null(newscale)) {
          slab <- x$slab
       } else {
          slab <- seq_len(k.new)
+         if (!is.null(rnames))
+            slab <- rnames
       }
    }
 
@@ -430,7 +451,7 @@ level, digits, transf, targs, vcov=FALSE, ...) {
 
    ### but when predicting just a single value, use "" as study label
 
-   if (k.new == 1L)
+   if (k.new == 1L && is.null(rnames))
       slab <- ""
 
    ### handle NAs
