@@ -1,8 +1,8 @@
 robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
-   .chkclass(class(x), must="rma.uni", notav=c("rma.uni.selmodel", "rma.ls"))
+   .chkclass(class(x), must="rma.uni", notav=c("rma.ls", "rma.gen", "rma.uni.selmodel"))
 
    if (missing(cluster))
       stop(mstyle$stop("Must specify 'cluster' variable."))
@@ -22,8 +22,10 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
    #########################################################################
 
    ### process cluster variable
-   ### note: cluster variable is assumed to be of the same length as the original data passed to the model fitting function
-   ###       so we have to apply the same subsetting (if necessary) and removing of missings as done during model fitting
+
+   ### note: cluster variable must be of the same length as the original dataset
+   ###       so we have to apply the same subsetting (if necessary) and removing
+   ###       of NAs as was done during model fitting
 
    mf <- match.call()
    cluster <- .getx("cluster", mf=mf, data=x$data)
@@ -31,8 +33,7 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
    if (length(cluster) != x$k.all)
       stop(mstyle$stop(paste0("Length of variable specified via 'cluster' (", length(cluster), ") does not correspond to the size of the original dataset (", x$k.all, ").")))
 
-   if (!is.null(x$subset))
-      cluster <- cluster[x$subset]
+   cluster <- .getsubset(cluster, x$subset)
 
    cluster <- cluster[x$not.na]
 
@@ -53,7 +54,7 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
 
    ### check if dfs are positive (note: this also handles the case where there is a single cluster)
 
-   if (dfs <= 0)
+   if (!clubSandwich && dfs <= 0)
       stop(mstyle$stop(paste0("Number of clusters (", n, ") must be larger than the number of fixed effects (", x$p, ").")))
 
    ### use clubSandwich if requested to do so
@@ -65,16 +66,10 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
 
       ### check for vcov, coef_test, conf_test, and wald_test arguments in ... and set values accordingly
 
-      if (is.null(ddd$vcov)) {
-         ddd$vcov <- "CR2"
-      } else {
-         ddd$vcov <- match.arg(ddd$vcov, c("CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3"))
-      }
-      if (is.null(ddd$coef_test)) {
-         ddd$coef_test <- "Satterthwaite"
-      } else {
-         ddd$coef_test <- match.arg(ddd$coef_test, c("z", "naive-t", "naive-tp", "Satterthwaite", "saddlepoint"))
-      }
+      ddd$vcov <- .chkddd(ddd$vcov, "CR2", match.arg(ddd$vcov, c("CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3")))
+
+      ddd$coef_test <- .chkddd(ddd$coef_test, "Satterthwaite", match.arg(ddd$coef_test, c("z", "naive-t", "naive-tp", "Satterthwaite", "saddlepoint")))
+
       if (is.null(ddd$conf_test)) {
          ddd$conf_test <- ddd$coef_test
          if (ddd$conf_test == "saddlepoint") {
@@ -84,11 +79,8 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
       } else {
          ddd$conf_test <- match.arg(ddd$conf_test, c("z", "naive-t", "naive-tp", "Satterthwaite"))
       }
-      if (is.null(ddd$wald_test)) {
-         ddd$wald_test <- "HTZ"
-      } else {
-         ddd$wald_test <- match.arg(ddd$wald_test, c("chi-sq", "Naive-F", "Naive-Fp", "HTA", "HTB", "HTZ", "EDF", "EDT"))
-      }
+
+      ddd$wald_test <- .chkddd(ddd$wald_test, "HTZ", match.arg(ddd$wald_test, c("chi-sq", "Naive-F", "Naive-Fp", "HTA", "HTB", "HTZ", "EDF", "EDT")))
 
       ### calculate cluster-robust var-cov matrix of the estimated fixed effects
 
@@ -98,7 +90,7 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
          stop(mstyle$stop("Could not obtain the cluster-robust variance-covariance matrix (use verbose=TRUE for more details)."))
 
       #meat <- try(clubSandwich::vcovCR(x, cluster=cluster, type=ddd$vcov, form="estfun"), silent=!isTRUE(ddd$verbose))
-      meat <- NA
+      meat <- NA_real_
 
       ### obtain cluster-robust inferences
 
@@ -114,14 +106,16 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
 
       if (x$int.only) {
 
-         cs.wald <- NA
+         cs.wald <- NA_real_
 
       } else {
 
          cs.wald <- try(clubSandwich::Wald_test(x, cluster=cluster, vcov=vb, test=ddd$wald_test, constraints=clubSandwich::constrain_zero(x$btt)), silent=!isTRUE(ddd$verbose))
 
-         if (inherits(cs.wald, "try-error"))
-            stop(mstyle$stop("Could not obtain the cluster-robust Wald test (use verbose=TRUE for more details)."))
+         if (inherits(cs.wald, "try-error")) {
+            warning(mstyle$warning("Could not obtain the cluster-robust omnibus Wald test (use verbose=TRUE for more details)."), call.=FALSE)
+            cs.wald <- list(Fstat=NA_real_, df_num=NA_integer_, df_denom=NA_real_)
+         }
 
       }
 
@@ -131,11 +125,12 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
 
       beta  <- x$beta
       se    <- cs.coef$SE
-      zval  <- cs.coef$tstat
+      zval  <- ifelse(is.infinite(cs.coef$tstat), NA_real_, cs.coef$tstat)
       pval  <- switch(ddd$coef_test, "z" = cs.coef$p_z,  "naive-t" = cs.coef$p_t,  "naive-tp" = cs.coef$p_tp,  "Satterthwaite" = cs.coef$p_Satt, "saddlepoint" = cs.coef$p_saddle)
-      dfs   <- switch(ddd$coef_test, "z" = cs.coef$df_z, "naive-t" = cs.coef$df_t, "naive-tp" = cs.coef$df_tp, "Satterthwaite" = cs.coef$df,     "saddlepoint" = NA)
-      ci.lb <- cs.conf$CI_L # note: if ddd$coef_test != ddd$conf_test, dfs for CI may be different
-      ci.ub <- cs.conf$CI_U
+      dfs   <- switch(ddd$coef_test, "z" = cs.coef$df_z, "naive-t" = cs.coef$df_t, "naive-tp" = cs.coef$df_tp, "Satterthwaite" = cs.coef$df,     "saddlepoint" = NA_real_)
+      dfs   <- ifelse(is.na(dfs), NA_real_, dfs) # ifelse() part to change NaN into just NA
+      ci.lb <- ifelse(is.na(cs.conf$CI_L), NA_real_, cs.conf$CI_L) # note: if ddd$coef_test != ddd$conf_test, dfs for CI may be different
+      ci.ub <- ifelse(is.na(cs.conf$CI_U), NA_real_, cs.conf$CI_U)
 
       if (x$int.only) {
          QM   <- max(0, zval^2)
@@ -143,7 +138,7 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
          QMp  <- pval
       } else {
          QM   <- max(0, cs.wald$Fstat)
-         QMdf <- c(cs.wald$df_num, cs.wald$df_denom)
+         QMdf <- c(cs.wald$df_num, max(0, cs.wald$df_denom))
          QMp  <- cs.wald$p_val
       }
 
@@ -234,6 +229,12 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
          vbest <- "CR1.S2"
       }
 
+      ### check for elements in vb that are essentially 0
+
+      is0 <- diag(vb) < 100 * .Machine$double.eps
+      vb[is0,] <- NA_real_
+      vb[,is0] <- NA_real_
+
       ### prepare results
 
       beta <- x$beta
@@ -247,8 +248,10 @@ robust.rma.uni <- function(x, cluster, adjust=TRUE, clubSandwich=FALSE, digits,
 
       QM <- try(as.vector(t(beta)[x$btt] %*% chol2inv(chol(vb[x$btt,x$btt])) %*% beta[x$btt]), silent=TRUE)
 
-      if (inherits(QM, "try-error"))
-         QM <- NA
+      if (inherits(QM, "try-error") || is.na(QM)) {
+         warning(mstyle$warning("Could not obtain the cluster-robust omnibus Wald test."), call.=FALSE)
+         QM <- NA_real_
+      }
 
       QM   <- QM / x$m # note: m is the number of coefficients in btt, not the number of clusters
       QMdf <- c(x$m, dfs)
