@@ -2,7 +2,7 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
 
    #########################################################################
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(x), must="rma.uni", notav=c("robust.rma", "rma.ls", "rma.gen", "rma.uni.selmodel"))
 
@@ -27,7 +27,7 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
    ### determine side (if none is specified)
 
    if (is.null(side)) {
-      args <- list(yi=yi, vi=vi, weights=wi, mods=sqrt(vi), method=x$method, weighted=x$weighted, outlist="beta=beta", ...)
+      args <- list(yi=yi, vi=vi, weights=wi, mods=sqrt(vi), method=x$method, weighted=x$weighted, control=x$control, outlist="beta=beta", ...)
       res <- suppressWarnings(.do.call(rma.uni, args))
       ### TODO: add check in case there are problems with fitting the model
       if (res$beta[2] < 0) {
@@ -57,15 +57,15 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
    k <- length(yi)
 
    k0.sav <- -1
-   k0     <-  0 ### estimated number of missing studies
-   iter   <-  0 ### iteration counter
+   k0     <-  0 # estimated number of missing studies
+   iter   <-  0 # iteration counter
 
    if (verbose)
       cat("\n")
 
    while (abs(k0 - k0.sav) > 0) {
 
-      k0.sav <- k0 ### save current value of k0
+      k0.sav <- k0 # save current value of k0
 
       iter <- iter + 1
 
@@ -78,16 +78,16 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
       vi.t <- vi[seq_len(k-k0)]
       wi.t <- wi[seq_len(k-k0)]
 
-      args <- list(yi=yi.t, vi=vi.t, weights=wi.t, method=x$method, weighted=x$weighted, outlist="beta=beta", ...)
+      args <- list(yi=yi.t, vi=vi.t, weights=wi.t, method=x$method, weighted=x$weighted, control=x$control, outlist="beta=beta", ...)
       res <- suppressWarnings(.do.call(rma.uni, args))
 
       ### intercept estimate based on truncated data
 
       beta <- c(res$beta)
 
-      yi.c     <- yi - beta                            ### centered values
-      yi.c.r   <- rank(abs(yi.c), ties.method="first") ### ranked absolute centered values
-      yi.c.r.s <- sign(yi.c) * yi.c.r                  ### signed ranked centered values
+      yi.c     <- yi - beta                            # centered values
+      yi.c.r   <- rank(abs(yi.c), ties.method="first") # ranked absolute centered values
+      yi.c.r.s <- sign(yi.c) * yi.c.r                  # signed ranked centered values
 
       ### estimate the number of missing studies with the R0 estimator
 
