@@ -1,7 +1,7 @@
 vcalc <- function(vi, cluster, subgroup, obs, type, time1, time2, grp1, grp2, w1, w2,
-data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
+data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, sparse=FALSE, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    ############################################################################
 
@@ -69,7 +69,7 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
    k <- length(vi)
 
    if (k == 1L)
-      stop(mstyle$stop("Processing terminated since k = 1."))
+      stop(mstyle$stop("Processing terminated since k = 1.")) # could also do: return(matrix(vi, nrow=1, ncol=1))
 
    #########################################################################
 
@@ -340,7 +340,12 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
       ### construct R matrix
 
-      R <- matrix(0, nrow=k, ncol=k)
+      if (sparse) {
+         R <- Matrix(0, nrow=k, ncol=k)
+      } else {
+         R <- matrix(0, nrow=k, ncol=k)
+      }
+
       diag(R) <- 1
 
       for (i in 2:k) {
@@ -401,18 +406,34 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
          stop(mstyle$stop(paste0("There ", ifelse(length(rvars) == 1L, "is 1 variable ", paste0("are ", length(rvars), " variables ")), "specified via 'rvars', but there are clusters with more rows.")))
 
       if (max(k.cluster) != length(rvars))
-         stop(mstyle$stop(paste0("There ", ifelse(length(rvars) == 1L, "is 1 variable ", paste0("are ", length(rvars), " variables ")), "specified via 'rvars', but no cluster with this many more rows.")))
+         stop(mstyle$stop(paste0("There ", ifelse(length(rvars) == 1L, "is 1 variable ", paste0("are ", length(rvars), " variables ")), "specified via 'rvars', but no cluster with this many rows.")))
 
       ### construct R matrix based on rvars
 
-      R <- lapply(split(rvars, cluster), function(x) {
-         k <- nrow(x)
-         x <- x[seq_len(k)]
-         x[upper.tri(x)] <- t(x)[upper.tri(x)]
-         as.matrix(x)
-         })
+      R <- list()
 
-      R <- bldiag(R, order=cluster)
+      for (i in seq_len(n)) {
+         x <- rvars[cluster == ucluster[i],]
+         x <- x[seq_len(nrow(x))]
+         if (anyNA(x[lower.tri(x, diag=TRUE)]))
+            warning(mstyle$warning(paste0("There are missing values in 'rvals' for cluster ", ucluster[i], ".")), call.=FALSE)
+         x[upper.tri(x)] <- t(x)[upper.tri(x)]
+         R[[i]] <- as.matrix(x)
+      }
+
+      names(R) <- ucluster
+
+      #R <- lapply(split(rvars, cluster), function(x) {
+      #   k <- nrow(x)
+      #   x <- x[seq_len(k)]
+      #   x[upper.tri(x)] <- t(x)[upper.tri(x)]
+      #   as.matrix(x)
+      #   })
+
+      #R <- bldiag(R, order=cluster)
+
+      R <- bldiag(R)
+      R <- Matrix(R, sparse=TRUE)
 
    }
 
@@ -428,14 +449,14 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
          Ri <- R[cluster == ucluster[i], cluster == ucluster[i]]
 
-         if (!anyNA(Ri) && any(eigen(Ri, symmetric=TRUE, only.values=TRUE)$values <= .Machine$double.eps)) {
+         if (!anyNA(Ri) && !.chkpd(Ri)) {
 
             if (nearpd) {
                Ri <- try(as.matrix(nearPD(Ri, corr=TRUE)$mat), silent=TRUE)
                if (inherits(Ri, "try-error")) {
                   warning(mstyle$warning(paste0("Using nearPD() failed in cluster ", ucluster[i], ".")), call.=FALSE)
                } else {
-                  if (!anyNA(Ri) && any(eigen(Ri, symmetric=TRUE, only.values=TRUE)$values <= .Machine$double.eps))
+                  if (!anyNA(Ri) && !.chkpd(Ri))
                      warning(mstyle$warning(paste0("The var-cov matrix still appears to be not positive definite in cluster ", ucluster[i], " even after nearPD().")), call.=FALSE)
                   R[cluster == ucluster[i], cluster == ucluster[i]] <- Ri
                }
@@ -453,9 +474,14 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
    ### turn R into V
 
-   S <- diag(sqrt(as.vector(vi)), nrow=k, ncol=k)
+   vi <- as.vector(vi)
+
+   S <- Diagonal(k, sqrt(vi))
    V <- S %*% R %*% S
 
+   if (!sparse)
+      V <- as.matrix(V)
+
    if (.isTRUE(ddd$retdat))
       V <- data.frame(cluster, type, obs, grp1, grp2, time1, time2, w1, w2, vi, V=V)
 
