@@ -1,6 +1,6 @@
 weights.rma.uni <- function(object, type="diagonal", ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="rma.uni", notav=c("rma.gen", "rma.uni.selmodel"))
 
