@@ -12,7 +12,7 @@ test_that("plot can be drawn.", {
 
    skip_on_cran()
 
-   opar <- par(no.readonly=TRUE)
+   png("images/test_plots_labbe_plot_test.png", res=200, width=1800, height=1600, type="cairo")
 
    ### decrease margins so the full space is used
    par(mar=c(5,4,1,2))
@@ -21,9 +21,11 @@ test_that("plot can be drawn.", {
    res <- rma(ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg, measure="RR")
 
    ### draw L'Abbé plot
-   labbe(res)
+   labbe(res, las=1, bty="l")
 
-   par(opar)
+   dev.off()
+
+   expect_true(.vistest("images/test_plots_labbe_plot_test.png", "images/test_plots_labbe_plot.png"))
 
 })
 
